@@ -1,8 +1,6 @@
 # --
 # Kernel/GenericInterface/Transport/HTTP/SOAP.pm - GenericInterface network transport interface for HTTP::SOAP
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: SOAP.pm,v 1.45.2.5 2012-12-05 15:06:30 cr Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,8 +18,7 @@ use Kernel::System::VariableCheck qw(:all);
 use Encode;
 use PerlIO;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.45.2.5 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -50,7 +47,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for my $Needed (qw(MainObject EncodeObject DebuggerObject TransportConfig ConfigObject)) {
+    for my $Needed (qw(MainObject EncodeObject DebuggerObject TransportConfig)) {
         $Self->{$Needed} = $Param{$Needed} || die "Got no $Needed!";
     }
 
@@ -184,8 +181,10 @@ sub ProviderProcessRequest {
     }
 
     # convert charset if necessary
-    my $ContentCharset = $1
-        if $ENV{'CONTENT_TYPE'} =~ m{ \A .* charset= ["']? ( [^"']+ ) ["']? \z }xmsi;
+    my $ContentCharset;
+    if ( $ENV{'CONTENT_TYPE'} =~ m{ \A .* charset= ["']? ( [^"']+ ) ["']? \z }xmsi ) {
+        $ContentCharset = $1;
+    }
     if ( $ContentCharset && $ContentCharset !~ m{ \A utf [-]? 8 \z }xmsi ) {
         $Content = $Self->{EncodeObject}->Convert2CharsetInternal(
             Text => $Content,
@@ -224,7 +223,7 @@ sub ProviderProcessRequest {
     my $Body = $Deserialized->body();
 
     # get operation from soap data
-    my $Operation = ( keys %{$Body} )[0];
+    my $Operation = ( sort keys %{$Body} )[0];
 
     # check operation against header
     if ( $OperationFromHeader && $Operation ne $OperationFromHeader ) {
@@ -344,7 +343,7 @@ sub ProviderGenerateResponse {
     }
     my $Serialized = SOAP::Serializer
         ->autotype(0)
-        ->default_ns( $Self->{TransportConfig}->{Config}->{NameSpace} )
+        ->ns( $Self->{TransportConfig}->{Config}->{NameSpace} )
         ->envelope(@CallData);
     my $SerializedFault = $@ || '';
     if ($SerializedFault) {
@@ -806,10 +805,6 @@ sub _Output {
         Data       => $Param{Content},
     );
 
-    # set keep-alive
-    my $ConfigKeepAlive = $Self->{ConfigObject}->Get('SOAP::Keep-Alive');
-    my $Connection = $ConfigKeepAlive ? 'Keep-Alive' : 'close';
-
     # in the constructor of this module STDIN and STDOUT are set to binmode without any additional
     # layer (according to the documentation this is the same as set :raw). Previous solutions for
     # binary responses requires the set of :raw or :utf8 according to IO layers.
@@ -820,14 +815,13 @@ sub _Output {
     # this solution to set the binmode in the constructor and then :utf8 layer before the response
     # is sent  apparently works in all situations. ( linux circumstances to requires :raw was no
     # reproducible, and not tested in this solution).
-    binmode STDOUT, ':utf8';
+    binmode STDOUT, ':utf8';    ## no critic
 
     # print data to http - '\r' is required according to HTTP RFCs
     my $StatusMessage = HTTP::Status::status_message( $Param{HTTPCode} );
     print STDOUT "$Protocol $Param{HTTPCode} $StatusMessage\r\n";
     print STDOUT "Content-Type: $ContentType; charset=UTF-8\r\n";
     print STDOUT "Content-Length: $ContentLength\r\n";
-    print STDOUT "Connection: $Connection\r\n";
     print STDOUT "\r\n";
     print STDOUT $Param{Content};
 
@@ -1190,9 +1184,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.45.2.5 $ $Date: 2012-12-05 15:06:30 $
-
-=cut
