@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketCompose.pm - to compose and send a message
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentTicketCompose.pm,v 1.161 2012/02/29 14:36:19 ep Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,9 +24,6 @@ use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 use Mail::Address;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.161 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -190,6 +185,7 @@ sub Run {
     my $Selected = $Self->{ParamObject}->GetParam( Param => 'CustomerSelected' ) || '';
 
     if ($CustomersNumber) {
+
         my $CustomerCounter = 1;
         for my $Count ( 1 ... $CustomersNumber ) {
             my $CustomerElement
@@ -201,7 +197,12 @@ sub Run {
                 || '';
             if ($CustomerElement) {
 
-                $GetParam{To} .= $CustomerElement . ',';
+                if ( $GetParam{To} ) {
+                    $GetParam{To} .= ', ' . $CustomerElement;
+                }
+                else {
+                    $GetParam{To} = $CustomerElement;
+                }
 
                 # check email address
                 my $CustomerErrorMsg = 'CustomerGenericServerErrorMsg';
@@ -221,7 +222,7 @@ sub Run {
                 }
 
                 my $CustomerDisabled = '';
-                my $CountAux         = $Count;
+                my $CountAux         = $CustomerCounter++;
                 if ( $CustomerError ne '' ) {
                     $CustomerDisabled = 'disabled="disabled"';
                     $CountAux         = $Count . 'Error';
@@ -251,6 +252,7 @@ sub Run {
         = $Self->{ParamObject}->GetParam( Param => 'CustomerTicketCounterCcCustomer' ) || 0;
 
     if ($CustomersNumberCc) {
+        my $CustomerCounterCc = 1;
         for my $Count ( 1 ... $CustomersNumberCc ) {
             my $CustomerElementCc
                 = $Self->{ParamObject}->GetParam( Param => 'CcCustomerTicketText_' . $Count );
@@ -262,7 +264,12 @@ sub Run {
 
             if ($CustomerElementCc) {
 
-                $GetParam{Cc} .= $CustomerElementCc . ',';
+                if ( $GetParam{Cc} ) {
+                    $GetParam{Cc} .= ', ' . $CustomerElementCc;
+                }
+                else {
+                    $GetParam{Cc} = $CustomerElementCc;
+                }
 
                 # check email address
                 my $CustomerErrorMsgCc = 'CustomerGenericServerErrorMsg';
@@ -282,7 +289,7 @@ sub Run {
                 }
 
                 my $CustomerDisabledCc = '';
-                my $CountAuxCc         = $Count;
+                my $CountAuxCc         = $CustomerCounterCc++;
                 if ( $CustomerErrorCc ne '' ) {
                     $CustomerDisabledCc = 'disabled="disabled"';
                     $CountAuxCc         = $Count . 'Error';
@@ -311,6 +318,7 @@ sub Run {
         = $Self->{ParamObject}->GetParam( Param => 'CustomerTicketCounterBccCustomer' ) || 0;
 
     if ($CustomersNumberBcc) {
+        my $CustomerCounterBcc = 1;
         for my $Count ( 1 ... $CustomersNumberBcc ) {
             my $CustomerElementBcc
                 = $Self->{ParamObject}->GetParam( Param => 'BccCustomerTicketText_' . $Count );
@@ -323,7 +331,12 @@ sub Run {
 
             if ($CustomerElementBcc) {
 
-                $GetParam{Bcc} .= $CustomerElementBcc . ',';
+                if ( $GetParam{Bcc} ) {
+                    $GetParam{Bcc} .= ', ' . $CustomerElementBcc;
+                }
+                else {
+                    $GetParam{Bcc} = $CustomerElementBcc;
+                }
 
                 # check email address
                 my $CustomerErrorMsgBcc = 'CustomerGenericServerErrorMsg';
@@ -343,7 +356,7 @@ sub Run {
                 }
 
                 my $CustomerDisabledBcc = '';
-                my $CountAuxBcc         = $Count;
+                my $CountAuxBcc         = $CustomerCounterBcc++;
                 if ( $CustomerErrorBcc ne '' ) {
                     $CustomerDisabledBcc = 'disabled="disabled"';
                     $CountAuxBcc         = $Count . 'Error';
@@ -387,7 +400,7 @@ sub Run {
     # convert dynamic field values into a structure for ACLs
     my %DynamicFieldACLParameters;
     DYNAMICFIELD:
-    for my $DynamicField ( keys %DynamicFieldValues ) {
+    for my $DynamicField ( sort keys %DynamicFieldValues ) {
         next DYNAMICFIELD if !$DynamicField;
         next DYNAMICFIELD if !$DynamicFieldValues{$DynamicField};
 
@@ -535,6 +548,10 @@ sub Run {
         # run compose modules
         if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq 'HASH' )
         {
+
+            # use ticket QueueID in compose modules
+            $GetParam{QueueID} = $Ticket{QueueID};
+
             my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') };
             for my $Job ( sort keys %Jobs ) {
 
@@ -579,6 +596,10 @@ sub Run {
             # check if field has PossibleValues property in its configuration
             if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
 
+                # convert possible values key => value to key => key for ACLs usign a Hash slice
+                my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} };
+                @AclData{ keys %AclData } = keys %AclData;
+
                 # set possible values filter from ACLs
                 my $ACL = $Self->{TicketObject}->TicketAcl(
                     %GetParam,
@@ -586,12 +607,16 @@ sub Run {
                     TicketID      => $Self->{TicketID},
                     ReturnType    => 'Ticket',
                     ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data          => $DynamicFieldConfig->{Config}->{PossibleValues},
+                    Data          => \%AclData,
                     UserID        => $Self->{UserID},
                 );
                 if ($ACL) {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
-                    $PossibleValuesFilter = \%Filter;
+
+                    # convert Filer key => key back to key => value using map
+                    %{$PossibleValuesFilter}
+                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
+                        keys %Filter;
                 }
             }
 
@@ -652,7 +677,7 @@ sub Run {
                     %GetParam,
                 ),
                 ResponseFormat => $Self->{LayoutObject}->Ascii2Html( Text => $GetParam{Body} ),
-                Errors => \%Error,
+                Errors         => \%Error,
                 MultipleCustomer    => \@MultipleCustomer,
                 MultipleCustomerCc  => \@MultipleCustomerCc,
                 MultipleCustomerBcc => \@MultipleCustomerBcc,
@@ -691,13 +716,15 @@ sub Run {
 
         # get recipients
         my $Recipients = '';
+        LINE:
         for my $Line (qw(To Cc Bcc)) {
-            if ( $GetParam{$Line} ) {
-                if ($Recipients) {
-                    $Recipients .= ',';
-                }
-                $Recipients .= $GetParam{$Line};
+
+            next LINE if !$GetParam{$Line};
+
+            if ($Recipients) {
+                $Recipients .= ', ';
             }
+            $Recipients .= $GetParam{$Line};
         }
 
         my $MimeType = 'text/plain';
@@ -849,6 +876,10 @@ sub Run {
 
         # run compose modules
         if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq 'HASH' ) {
+
+            # use ticket QueueID in compose modules
+            $GetParam{QueueID} = $Ticket{QueueID};
+
             my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') };
             for my $Job ( sort keys %Jobs ) {
 
@@ -865,6 +896,11 @@ sub Run {
                 # run module
                 my %Data = $Object->Data( %GetParam, Config => $Jobs{$Job} );
 
+                # get AJAX param values
+                if ( $Object->can('GetParamAJAX') ) {
+                    %GetParam = ( %GetParam, $Object->GetParamAJAX(%GetParam) )
+                }
+
                 my $Key = $Object->Option( %GetParam, Config => $Jobs{$Job} );
                 if ($Key) {
                     push(
@@ -902,6 +938,10 @@ sub Run {
                 DynamicFieldConfig => $DynamicFieldConfig,
             );
 
+            # convert possible values key => value to key => key for ACLs usign a Hash slice
+            my %AclData = %{$PossibleValues};
+            @AclData{ keys %AclData } = keys %AclData;
+
             # set possible values filter from ACLs
             my $ACL = $Self->{TicketObject}->TicketAcl(
                 %GetParam,
@@ -910,12 +950,14 @@ sub Run {
                 QueueID       => $Self->{QueueID},
                 ReturnType    => 'Ticket',
                 ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                Data          => $PossibleValues,
+                Data          => \%AclData,
                 UserID        => $Self->{UserID},
             );
             if ($ACL) {
                 my %Filter = $Self->{TicketObject}->TicketAclData();
-                $PossibleValues = \%Filter;
+
+                # convert Filer key => key back to key => value using map
+                %{$PossibleValues} = map { $_ => $PossibleValues->{$_} } keys %Filter;
             }
 
             # add dynamic field to the list of fields to update
@@ -1165,7 +1207,11 @@ sub Run {
                 # replace To with customers database address
                 if ( $Self->{ConfigObject}->Get('Ticket::Frontend::ComposeReplaceSenderAddress') ) {
                     $Output .= $Self->{LayoutObject}->Notify(
-                        Data => "To: ($Data{To}) replaced with database email!",
+                        Data => $Self->{LayoutObject}->{LanguageObject}->Get(
+                            'Address %s replaced with registered customer address.", "'
+                                . $Data{ToEmail}
+                        ),
+
                     );
                     $Data{To} = $Customer{UserEmail};
                 }
@@ -1173,7 +1219,7 @@ sub Run {
                 # add customers database address to Cc
                 else {
                     $Output .= $Self->{LayoutObject}->Notify(
-                        Data => "Cc: ($Customer{UserEmail}) added database email!",
+                        Info => "Customer automatically added in Cc.",
                     );
                     if ( $Data{Cc} ) {
                         $Data{Cc} .= ', ' . $Customer{UserEmail};
@@ -1266,7 +1312,7 @@ $QData{"Signature"}
             $ResponseFormat =~ s/&quot;/"/gi;
 
             # quote all non html content to have it correct in edit area
-            for my $Key ( keys %DataHTML ) {
+            for my $Key ( sort keys %DataHTML ) {
                 next if !$DataHTML{$Key};
                 next if $Key eq 'Salutation';
                 next if $Key eq 'Body';
@@ -1315,6 +1361,10 @@ $QData{"Signature"}
             # check if field has PossibleValues property in its configuration
             if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
 
+                # convert possible values key => value to key => key for ACLs usign a Hash slice
+                my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} };
+                @AclData{ keys %AclData } = keys %AclData;
+
                 # set possible values filter from ACLs
                 my $ACL = $Self->{TicketObject}->TicketAcl(
                     %GetParam,
@@ -1322,12 +1372,16 @@ $QData{"Signature"}
                     TicketID      => $Self->{TicketID},
                     ReturnType    => 'Ticket',
                     ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data          => $DynamicFieldConfig->{Config}->{PossibleValues},
+                    Data          => \%AclData,
                     UserID        => $Self->{UserID},
                 );
                 if ($ACL) {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
-                    $PossibleValuesFilter = \%Filter;
+
+                    # convert Filer key => key back to key => value using map
+                    %{$PossibleValuesFilter}
+                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
+                        keys %Filter;
                 }
             }
 
@@ -1360,6 +1414,34 @@ $QData{"Signature"}
         # build references if exist
         my $References = ( $Data{MessageID} || '' ) . ( $Data{References} || '' );
 
+        # run compose modules
+        if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq 'HASH' )
+        {
+            my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') };
+            for my $Job ( sort keys %Jobs ) {
+
+                # load module
+                if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
+                    return $Self->{LayoutObject}->FatalError();
+                }
+                my $Object = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug} );
+
+                # get params
+                for ( $Object->Option( %GetParam, Config => $Jobs{$Job} ) ) {
+                    $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
+                }
+
+                # run module
+                $Object->Run( %GetParam, Config => $Jobs{$Job} );
+
+                # get errors
+                %Error = (
+                    %Error,
+                    $Object->Error( %GetParam, Config => $Jobs{$Job} ),
+                );
+            }
+        }
+
         # build view ...
         $Output .= $Self->_Mask(
             TicketID   => $Self->{TicketID},
@@ -1453,7 +1535,7 @@ sub _Mask {
 
     # prepare errors!
     if ( $Param{Errors} ) {
-        for ( keys %{ $Param{Errors} } ) {
+        for ( sort keys %{ $Param{Errors} } ) {
             $Param{$_} = $Self->{LayoutObject}->Ascii2Html( Text => $Param{Errors}->{$_} );
         }
     }
@@ -1481,14 +1563,6 @@ sub _Mask {
         $Param{CcInvalid} = ''
     }
 
-    $Self->{LayoutObject}->Block(
-        Name => 'Content',
-        Data => {
-            FormID => $Self->{FormID},
-            %Param,
-        },
-    );
-
     # Cc
     my $CustomerCounterCc = 0;
     if ( $Param{MultipleCustomerCc} ) {
@@ -1510,6 +1584,10 @@ sub _Mask {
         }
     }
 
+    if ( !$CustomerCounterCc ) {
+        $Param{CcCustomerHiddenContainer} = 'Hidden';
+    }
+
     # set customer counter
     $Self->{LayoutObject}->Block(
         Name => 'CcMultipleCustomerCounter',
@@ -1539,6 +1617,10 @@ sub _Mask {
         }
     }
 
+    if ( !$CustomerCounterBcc ) {
+        $Param{BccCustomerHiddenContainer} = 'Hidden';
+    }
+
     # set customer counter
     $Self->{LayoutObject}->Block(
         Name => 'BccMultipleCustomerCounter',
@@ -1568,6 +1650,10 @@ sub _Mask {
         }
     }
 
+    if ( !$CustomerCounter ) {
+        $Param{CustomerHiddenContainer} = 'Hidden';
+    }
+
     # set customer counter
     $Self->{LayoutObject}->Block(
         Name => 'MultipleCustomerCounter',
@@ -1627,38 +1713,6 @@ sub _Mask {
         },
     );
 
-    # run compose modules
-    if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq 'HASH' ) {
-        my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') };
-        for my $Job ( sort keys %Jobs ) {
-
-            # load module
-            if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
-                return $Self->{LayoutObject}->FatalError();
-            }
-            my $Object = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug}, );
-
-            # get params
-            for ( sort keys %{ $Param{GetParam} } ) {
-                if ( !$Param{GetParam}->{$_} && $Param{$_} ) {
-                    $Param{GetParam}->{$_} = $Param{$_};
-                }
-            }
-            for ( $Object->Option( %Param, %{ $Param{GetParam} }, Config => $Jobs{$Job} ) ) {
-                $Param{GetParam}->{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
-            }
-
-            # run module
-            $Object->Run( %Param, %{ $Param{GetParam} }, Config => $Jobs{$Job} );
-
-            # get errors
-            %{ $Param{Errors} } = (
-                %{ $Param{Errors} },
-                $Object->Error( %{ $Param{GetParam} }, Config => $Jobs{$Job} )
-            );
-        }
-    }
-
     # Dynamic fields
     # cycle trough the activated Dynamic Fields for this screen
     DYNAMICFIELD:
@@ -1759,6 +1813,11 @@ sub _Mask {
 
     # add rich text editor
     if ( $Self->{LayoutObject}->{BrowserRichText} ) {
+
+        # use height/width defined for this screen
+        $Param{RichTextHeight} = $Self->{Config}->{RichTextHeight} || 0;
+        $Param{RichTextWidth}  = $Self->{Config}->{RichTextWidth}  || 0;
+
         $Self->{LayoutObject}->Block(
             Name => 'RichText',
             Data => \%Param,
@@ -1775,7 +1834,13 @@ sub _Mask {
     }
 
     # create & return output
-    return $Self->{LayoutObject}->Output( TemplateFile => 'AgentTicketCompose', Data => \%Param );
+    return $Self->{LayoutObject}->Output(
+        TemplateFile => 'AgentTicketCompose',
+        Data         => {
+            FormID => $Self->{FormID},
+            %Param,
+        },
+    );
 }
 
 sub _GetFieldsToUpdate {
