@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/CustomerTicketMessage.pm - to handle customer messages
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: CustomerTicketMessage.pm,v 1.100.2.3 2012/07/01 12:29:48 ub Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -22,9 +20,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.100.2.3 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -76,6 +71,10 @@ sub Run {
         $GetParam{$Key} = $Self->{ParamObject}->GetParam( Param => $Key );
     }
 
+    # ACL compatibility translation
+    my %ACLCompatGetParam;
+    $ACLCompatGetParam{OwnerID} = $GetParam{NewUserID};
+
     # get Dynamic fields from ParamObject
     my %DynamicFieldValues;
 
@@ -96,7 +95,7 @@ sub Run {
     # convert dynamic field values into a structure for ACLs
     my %DynamicFieldACLParameters;
     DYNAMICFIELD:
-    for my $DynamicField ( keys %DynamicFieldValues ) {
+    for my $DynamicField ( sort keys %DynamicFieldValues ) {
         next DYNAMICFIELD if !$DynamicField;
         next DYNAMICFIELD if !$DynamicFieldValues{$DynamicField};
 
@@ -117,6 +116,15 @@ sub Run {
                     $Param{ToSelected} = $QueueDefaultID . '||' . $QueueDefault;
                 }
             }
+
+            # warn if there is no (valid) default queue and the customer can't select one
+            elsif ( !$Self->{Config}->{'Queue'} ) {
+                $Self->{LayoutObject}->CustomerFatalError(
+                    Message => 'Check SysConfig setting for ' . $Self->{Action} . '::QueueDefault.',
+                    Comment => 'Please contact your administrator',
+                );
+                return;
+            }
         }
 
         # create html strings for all dynamic fields
@@ -132,6 +140,10 @@ sub Run {
             # check if field has PossibleValues property in its configuration
             if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
 
+                # convert possible values key => value to key => key for ACLs usign a Hash slice
+                my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} };
+                @AclData{ keys %AclData } = keys %AclData;
+
                 # set possible values filter from ACLs
                 my $ACL = $Self->{TicketObject}->TicketAcl(
                     %GetParam,
@@ -139,12 +151,16 @@ sub Run {
                     TicketID       => $Self->{TicketID},
                     ReturnType     => 'Ticket',
                     ReturnSubType  => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data           => $DynamicFieldConfig->{Config}->{PossibleValues},
+                    Data           => \%AclData,
                     CustomerUserID => $Self->{UserID},
                 );
                 if ($ACL) {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
-                    $PossibleValuesFilter = \%Filter;
+
+                    # convert Filer key => key back to key => value using map
+                    %{$PossibleValuesFilter}
+                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
+                        keys %Filter;
                 }
             }
 
@@ -155,12 +171,10 @@ sub Run {
                 PossibleValuesFilter => $PossibleValuesFilter,
                 Mandatory =>
                     $Self->{Config}->{DynamicField}->{ $DynamicFieldConfig->{Name} } == 2,
-                LayoutObject => $Self->{LayoutObject},
-                ParamObject  => $Self->{ParamObject},
-
-                # CustomerTicketMessage does not support AJAXUpdate
-                AJAXUpdate     => 0,
-                SubmitOnChange => 1,
+                LayoutObject    => $Self->{LayoutObject},
+                ParamObject     => $Self->{ParamObject},
+                AJAXUpdate      => 1,
+                UpdatableFields => $Self->_GetFieldsToUpdate(),
                 );
         }
 
@@ -168,6 +182,7 @@ sub Run {
         my $Output .= $Self->{LayoutObject}->CustomerHeader();
         $Output    .= $Self->{LayoutObject}->CustomerNavigationBar();
         $Output    .= $Self->_MaskNew(
+            %GetParam,
             QueueID          => $QueueDefaultID,
             ToSelected       => $Param{ToSelected},
             DynamicFieldHTML => \%DynamicFieldHTML,
@@ -200,6 +215,25 @@ sub Run {
             }
         }
 
+        # use default if ticket type is not available in screen but activated on system
+        if ( $Self->{ConfigObject}->Get('Ticket::Type') && !$Self->{Config}->{'TicketType'} ) {
+            my %TypeList = reverse $Self->{TicketObject}->TicketTypeList(
+                %Param,
+                Action         => $Self->{Action},
+                CustomerUserID => $Self->{UserID},
+            );
+            $GetParam{TypeID} = $TypeList{ $Self->{Config}->{'TicketTypeDefault'} };
+            if ( !$GetParam{TypeID} ) {
+                $Self->{LayoutObject}->CustomerFatalError(
+                    Message => 'Check SysConfig setting for '
+                        . $Self->{Action}
+                        . '::TicketTypeDefault.',
+                    Comment => 'Please contact your administrator',
+                );
+                return;
+            }
+        }
+
         # If is an action about attachments
         my $IsUpload = 0;
 
@@ -247,6 +281,10 @@ sub Run {
             # check if field has PossibleValues property in its configuration
             if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
 
+                # convert possible values key => value to key => key for ACLs usign a Hash slice
+                my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} };
+                @AclData{ keys %AclData } = keys %AclData;
+
                 # set possible values filter from ACLs
                 my $ACL = $Self->{TicketObject}->TicketAcl(
                     %GetParam,
@@ -254,12 +292,16 @@ sub Run {
                     TicketID       => $Self->{TicketID},
                     ReturnType     => 'Ticket',
                     ReturnSubType  => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data           => $DynamicFieldConfig->{Config}->{PossibleValues},
+                    Data           => \%AclData,
                     CustomerUserID => $Self->{UserID},
                 );
                 if ($ACL) {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
-                    $PossibleValuesFilter = \%Filter;
+
+                    # convert Filer key => key back to key => value using map
+                    %{$PossibleValuesFilter}
+                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
+                        keys %Filter;
                 }
             }
 
@@ -304,10 +346,8 @@ sub Run {
                 ErrorMessage => $ValidationResult->{ErrorMessage} || '',
                 LayoutObject => $Self->{LayoutObject},
                 ParamObject  => $Self->{ParamObject},
-
-                # CustomerTicketMessage does not support AJAXUpdate
-                AJAXUpdate     => 0,
-                SubmitOnChange => 1,
+                AJAXUpdate   => 1,
+                UpdatableFields => $Self->_GetFieldsToUpdate(),
                 );
         }
 
@@ -508,13 +548,258 @@ sub Run {
             OP => "Action=$NextScreen;TicketID=$TicketID",
         );
     }
-    my $Output = $Self->{LayoutObject}->CustomerHeader( Title => 'Error' );
-    $Output .= $Self->{LayoutObject}->CustomerError(
-        Message => 'No Subaction!!',
-        Comment => 'Please contact your administrator',
-    );
-    $Output .= $Self->{LayoutObject}->CustomerFooter();
-    return $Output;
+
+    elsif ( $Self->{Subaction} eq 'AJAXUpdate' ) {
+
+        my $Dest         = $Self->{ParamObject}->GetParam( Param => 'Dest' ) || '';
+        my $CustomerUser = $Self->{UserID};
+        my $QueueID      = '';
+        if ( $Dest =~ /^(\d{1,100})\|\|.+?$/ ) {
+            $QueueID = $1;
+        }
+
+        # get list type
+        my $TreeView = 0;
+        if ( $Self->{ConfigObject}->Get('Ticket::Frontend::ListType') eq 'tree' ) {
+            $TreeView = 1;
+        }
+
+        my $Tos = $Self->_GetTos(
+            %GetParam,
+            %ACLCompatGetParam,
+            QueueID => $QueueID,
+        );
+
+        my $NewTos;
+
+        if ($Tos) {
+            for my $KeyTo ( sort keys %{$Tos} ) {
+                $NewTos->{"$KeyTo||$Tos->{$KeyTo}"} = $Tos->{$KeyTo};
+            }
+        }
+        my $Priorities = $Self->_GetPriorities(
+            %GetParam,
+            %ACLCompatGetParam,
+            CustomerUserID => $CustomerUser || '',
+            QueueID        => $QueueID      || 1,
+        );
+        my $Services = $Self->_GetServices(
+            %GetParam,
+            %ACLCompatGetParam,
+            CustomerUserID => $CustomerUser || '',
+            QueueID        => $QueueID      || 1,
+        );
+        my $SLAs = $Self->_GetSLAs(
+            %GetParam,
+            %ACLCompatGetParam,
+            CustomerUserID => $CustomerUser || '',
+            QueueID        => $QueueID      || 1,
+            Services       => $Services,
+        );
+
+        # update Dynamic Fields Possible Values via AJAX
+        my @DynamicFieldAJAX;
+
+        # cycle trough the activated Dynamic Fields for this screen
+        DYNAMICFIELD:
+        for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+            next DYNAMICFIELD
+                if !$Self->{BackendObject}->IsAJAXUpdateable(
+                DynamicFieldConfig => $DynamicFieldConfig,
+                );
+            next DYNAMICFIELD if $DynamicFieldConfig->{ObjectType} ne 'Ticket';
+
+            my $PossibleValues = $Self->{BackendObject}->AJAXPossibleValuesGet(
+                DynamicFieldConfig => $DynamicFieldConfig,
+            );
+
+            # convert possible values key => value to key => key for ACLs usign a Hash slice
+            my %AclData = %{$PossibleValues};
+            @AclData{ keys %AclData } = keys %AclData;
+
+            # set possible values filter from ACLs
+            my $ACL = $Self->{TicketObject}->TicketAcl(
+                %GetParam,
+                %ACLCompatGetParam,
+                Action         => $Self->{Action},
+                QueueID        => $QueueID || 0,
+                ReturnType     => 'Ticket',
+                ReturnSubType  => 'DynamicField_' . $DynamicFieldConfig->{Name},
+                Data           => \%AclData,
+                CustomerUserID => $Self->{UserID},
+            );
+            if ($ACL) {
+                my %Filter = $Self->{TicketObject}->TicketAclData();
+
+                # convert Filer key => key back to key => value using map
+                %{$PossibleValues} = map { $_ => $PossibleValues->{$_} } keys %Filter;
+            }
+
+            # add dynamic field to the list of fields to update
+            push(
+                @DynamicFieldAJAX,
+                {
+                    Name        => 'DynamicField_' . $DynamicFieldConfig->{Name},
+                    Data        => $PossibleValues,
+                    SelectedID  => $DynamicFieldValues{ $DynamicFieldConfig->{Name} },
+                    Translation => $DynamicFieldConfig->{Config}->{TranslatableValues} || 0,
+                    Max         => 100,
+                }
+            );
+        }
+
+        my $JSON = $Self->{LayoutObject}->BuildSelectionJSON(
+            [
+                {
+                    Name         => 'Dest',
+                    Data         => $NewTos,
+                    SelectedID   => $Dest,
+                    Translation  => 0,
+                    PossibleNone => 0,
+                    TreeView     => $TreeView,
+                    Max          => 100,
+                },
+                {
+                    Name        => 'PriorityID',
+                    Data        => $Priorities,
+                    SelectedID  => $GetParam{PriorityID},
+                    Translation => 1,
+                    Max         => 100,
+                },
+                {
+                    Name         => 'ServiceID',
+                    Data         => $Services,
+                    SelectedID   => $GetParam{ServiceID},
+                    PossibleNone => 1,
+                    Translation  => 0,
+                    TreeView     => $TreeView,
+                    Max          => 100,
+                },
+                {
+                    Name         => 'SLAID',
+                    Data         => $SLAs,
+                    SelectedID   => $GetParam{SLAID},
+                    PossibleNone => 1,
+                    Translation  => 0,
+                    Max          => 100,
+                },
+                @DynamicFieldAJAX,
+            ],
+        );
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'application/json; charset=' . $Self->{LayoutObject}->{Charset},
+            Content     => $JSON,
+            Type        => 'inline',
+            NoCache     => 1,
+        );
+    }
+    else {
+        return $Self->{LayoutObject}->ErrorScreen(
+            Message => 'No Subaction!!',
+            Comment => 'Please contact your administrator',
+        );
+    }
+
+}
+
+sub _GetPriorities {
+    my ( $Self, %Param ) = @_;
+
+    # get priority
+    my %Priorities;
+    if ( $Param{QueueID} || $Param{TicketID} ) {
+        %Priorities = $Self->{TicketObject}->TicketPriorityList(
+            %Param,
+            Action         => $Self->{Action},
+            CustomerUserID => $Self->{UserID},
+        );
+    }
+    return \%Priorities;
+}
+
+sub _GetTypes {
+    my ( $Self, %Param ) = @_;
+
+    # get type
+    my %Type;
+    if ( $Param{QueueID} || $Param{TicketID} ) {
+        %Type = $Self->{TicketObject}->TicketTypeList(
+            %Param,
+            Action         => $Self->{Action},
+            CustomerUserID => $Self->{UserID},
+        );
+    }
+    return \%Type;
+}
+
+sub _GetServices {
+    my ( $Self, %Param ) = @_;
+
+    # get service
+    my %Service;
+
+    # check needed
+    return \%Service if !$Param{QueueID} && !$Param{TicketID};
+
+    # get options for default services for unknown customers
+    my $DefaultServiceUnknownCustomer
+        = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
+
+    # get service list
+    if ( $Param{CustomerUserID} || $DefaultServiceUnknownCustomer ) {
+        %Service = $Self->{TicketObject}->TicketServiceList(
+            %Param,
+            Action         => $Self->{Action},
+            CustomerUserID => $Self->{UserID},
+        );
+    }
+    return \%Service;
+}
+
+sub _GetSLAs {
+    my ( $Self, %Param ) = @_;
+
+    # get sla
+    my %SLA;
+    if ( $Param{ServiceID} && $Param{Services} && %{ $Param{Services} } ) {
+        if ( $Param{Services}->{ $Param{ServiceID} } ) {
+            %SLA = $Self->{TicketObject}->TicketSLAList(
+                %Param,
+                Action         => $Self->{Action},
+                CustomerUserID => $Self->{UserID},
+            );
+        }
+    }
+    return \%SLA;
+}
+
+sub _GetTos {
+    my ( $Self, %Param ) = @_;
+
+    # check own selection
+    my %NewTos = ( '', '-' );
+    my $Module = $Self->{ConfigObject}->Get('CustomerPanel::NewTicketQueueSelectionModule')
+        || 'Kernel::Output::HTML::CustomerNewTicketQueueSelectionGeneric';
+    if ( $Self->{MainObject}->Require($Module) ) {
+        my $Object = $Module->new( %{$Self}, Debug => $Self->{Debug}, );
+
+        # log loaded module
+        if ( $Self->{Debug} > 1 ) {
+            $Self->{LogObject}->Log(
+                Priority => 'debug',
+                Message  => "Module: $Module loaded!",
+            );
+        }
+        %NewTos = ( $Object->Run( Env => $Self, ACLParams => \%Param ), ( '', => '-' ) );
+    }
+    else {
+        return $Self->{LayoutObject}->FatalDie(
+            Message => "Could not load $Module!",
+        );
+    }
+
+    return \%NewTos;
 }
 
 sub _MaskNew {
@@ -553,7 +838,7 @@ sub _MaskNew {
 
         # build to string
         if (%NewTos) {
-            for ( keys %NewTos ) {
+            for ( sort keys %NewTos ) {
                 $NewTos{"$_||$NewTos{$_}"} = $NewTos{$_};
                 delete $NewTos{$_};
             }
@@ -604,12 +889,18 @@ sub _MaskNew {
     }
 
     # types
-    if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
+    if ( $Self->{ConfigObject}->Get('Ticket::Type') && $Self->{Config}->{'TicketType'} ) {
         my %Type = $Self->{TicketObject}->TicketTypeList(
             %Param,
             Action         => $Self->{Action},
             CustomerUserID => $Self->{UserID},
         );
+
+        if ( $Self->{Config}->{'TicketTypeDefault'} && !$Param{TypeID} ) {
+            my %ReverseType = reverse %Type;
+            $Param{TypeID} = $ReverseType{ $Self->{Config}->{'TicketTypeDefault'} };
+        }
+
         $Param{TypeStrg} = $Self->{LayoutObject}->BuildSelection(
             Data         => \%Type,
             Name         => 'TypeID',
@@ -684,7 +975,7 @@ sub _MaskNew {
 
     # prepare errors
     if ( $Param{Errors} ) {
-        for ( keys %{ $Param{Errors} } ) {
+        for ( sort keys %{ $Param{Errors} } ) {
             $Param{$_} = $Param{Errors}->{$_};
         }
     }
@@ -734,6 +1025,11 @@ sub _MaskNew {
 
     # add rich text editor
     if ( $Self->{LayoutObject}->{BrowserRichText} ) {
+
+        # use height/width defined for this screen
+        $Param{RichTextHeight} = $Self->{Config}->{RichTextHeight} || 0;
+        $Param{RichTextWidth}  = $Self->{Config}->{RichTextWidth}  || 0;
+
         $Self->{LayoutObject}->Block(
             Name => 'RichText',
             Data => \%Param,
@@ -747,4 +1043,32 @@ sub _MaskNew {
     );
 }
 
+sub _GetFieldsToUpdate {
+    my ( $Self, %Param ) = @_;
+
+    my @UpdatableFields;
+
+    # set the fields that can be updatable via AJAXUpdate
+    if ( !$Param{OnlyDynamicFields} ) {
+        @UpdatableFields
+            = qw( Dest ServiceID SLAID PriorityID );
+    }
+
+    # cycle trough the activated Dynamic Fields for this screen
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+        my $Updateable = $Self->{BackendObject}->IsAJAXUpdateable(
+            DynamicFieldConfig => $DynamicFieldConfig,
+        );
+
+        next DYNAMICFIELD if !$Updateable;
+
+        push @UpdatableFields, 'DynamicField_' . $DynamicFieldConfig->{Name};
+    }
+
+    return \@UpdatableFields;
+}
+
 1;
