@@ -1,8 +1,6 @@
 # --
 # Kernel/Output/HTML/LayoutAJAX.pm - provides generic HTML output
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: LayoutAJAX.pm,v 1.29 2011-12-09 02:50:26 cr Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,8 +12,7 @@ package Kernel::Output::HTML::LayoutAJAX;
 use strict;
 use warnings;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.29 $) [1];
+use vars qw(@ISA);
 
 =item BuildSelectionJSON()
 
