@@ -1,6 +1,6 @@
 # --
 # Kernel/Output/HTML/LayoutLinkObject.pm - provides generic HTML output for LinkObject
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,18 +14,6 @@ use warnings;
 
 use Kernel::System::LinkObject;
 
-=head1 NAME
-
-Kernel::Output::HTML::LayoutLinkObject - all LinkObject-related HTML functions
-
-=head1 SYNOPSIS
-
-All LinkObject-related HTML functions
-
-=head1 PUBLIC INTERFACE
-
-=over 4
-
 =item LinkObjectTableCreate()
 
 create a output table
@@ -796,14 +784,6 @@ sub _LinkObjectContentStringCreate {
         );
     }
 
-    elsif ( $Content->{Type} eq 'TimeLong' ) {
-        $Blockname = 'TimeLong';
-    }
-
-    elsif ( $Content->{Type} eq 'Date' ) {
-        $Blockname = 'Date';
-    }
-
     # prepare text
     elsif ( $Content->{Type} eq 'Text' || !$Content->{Type} ) {
 
@@ -884,15 +864,3 @@ sub _LoadLinkObjectLayoutBackend {
 =cut
 
 1;
-
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
