@@ -1,6 +1,6 @@
 # --
 # Kernel/Output/HTML/TicketMenuResponsible.pm
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,7 +20,7 @@ sub new {
     bless( $Self, $Type );
 
     # get needed objects
-    for (qw(ConfigObject LogObject DBObject LayoutObject UserID GroupObject TicketObject )) {
+    for (qw(ConfigObject LogObject DBObject LayoutObject UserID TicketObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
@@ -32,10 +32,7 @@ sub Run {
 
     # check needed stuff
     if ( !$Param{Ticket} ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => 'Need Ticket!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Ticket!' );
         return;
     }
 
@@ -74,40 +71,10 @@ sub Run {
         }
     }
 
-    # group check
-    if ( $Param{Config}->{Group} ) {
-        my @Items = split /;/, $Param{Config}->{Group};
-        my $AccessOk;
-        GROUP:
-        for my $Item (@Items) {
-            my ( $Permission, $Name ) = split /:/, $Item;
-            if ( !$Permission || !$Name ) {
-                $Self->{LogObject}->Log(
-                    Priority => 'error',
-                    Message  => "Invalid config for Key Group: '$Item'! "
-                        . "Need something like '\$Permission:\$Group;'",
-                );
-            }
-            my @Groups = $Self->{GroupObject}->GroupMemberList(
-                UserID => $Self->{UserID},
-                Type   => $Permission,
-                Result => 'Name',
-            );
-            next GROUP if !@Groups;
-
-            for my $Group (@Groups) {
-                if ( $Group eq $Name ) {
-                    $AccessOk = 1;
-                    last GROUP;
-                }
-            }
-        }
-        return if !$AccessOk;
-    }
-
     # check acl
-    my %ACLLookup = reverse( %{ $Param{ACL} || {} } );
-    return if ( !$ACLLookup{ $Param{Config}->{Action} } );
+    return
+        if defined $Param{ACL}->{ $Param{Config}->{Action} }
+        && !$Param{ACL}->{ $Param{Config}->{Action} };
 
     # return item
     return { %{ $Param{Config} }, %{ $Param{Ticket} }, %Param };
