@@ -1,6 +1,6 @@
 # --
 # Kernel/Output/HTML/ToolBarLink.pm
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -32,10 +32,7 @@ sub Run {
     # check needed stuff
     for (qw(Config)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
@@ -47,19 +44,16 @@ sub Run {
     }
 
     # get item definition
-    my $Text      = $Self->{LayoutObject}->{LanguageObject}->Translate( $Param{Config}->{Name} );
+    my $Text      = $Self->{LayoutObject}->{LanguageObject}->Get( $Param{Config}->{Name} );
     my $URL       = $Self->{LayoutObject}->{Baselink} . $Param{Config}->{Link};
     my $Priority  = $Param{Config}->{Priority};
     my $AccessKey = $Param{Config}->{AccessKey};
     my $CssClass  = $Param{Config}->{CssClass};
-    my $Icon      = $Param{Config}->{Icon};
-
     my %Return;
     $Return{$Priority} = {
         Block       => 'ToolBarItem',
         Description => $Text,
         Class       => $CssClass,
-        Icon        => $Icon,
         Link        => $URL,
         AccessKey   => $AccessKey,
     };
