@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/CheckItem.pm - the global spelling module
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::CheckItem;
@@ -11,28 +12,48 @@ package Kernel::System::CheckItem;
 use strict;
 use warnings;
 
-use Email::Valid;
-
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::Log',
-);
-
 =head1 NAME
 
 Kernel::System::CheckItem - check items
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 All item check functions.
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
 
-Don't use the constructor directly, use the ObjectManager instead:
+=cut
 
-    my $CheckItemObject = $Kernel::OM->Get('Kernel::System::CheckItem');
+=item new()
+
+create an object
+
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::CheckItem;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $CheckItemObject = Kernel::System::CheckItem->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
 
 =cut
 
@@ -43,10 +64,15 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # check needed objects
+    for my $Object (qw(ConfigObject LogObject MainObject)) {
+        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
+    }
+
     return $Self;
 }
 
-=head2 CheckError()
+=item CheckError()
 
 get the error of check item back
 
@@ -60,7 +86,7 @@ sub CheckError {
     return $Self->{Error};
 }
 
-=head2 CheckErrorType()
+=item CheckErrorType()
 
 get the error's type of check item back
 
@@ -74,7 +100,7 @@ sub CheckErrorType {
     return $Self->{ErrorType};
 }
 
-=head2 CheckEmail()
+=item CheckEmail()
 
 returns true if check was successful, if it's false, get the error message
 from CheckError()
@@ -90,46 +116,62 @@ sub CheckEmail {
 
     # check needed stuff
     if ( !$Param{Address} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Need Address!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Address!' );
         return;
     }
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     # check if it's to do
-    return 1 if !$ConfigObject->Get('CheckEmailAddresses');
+    return 1 if !$Self->{ConfigObject}->Get('CheckEmailAddresses');
 
     # check valid email addresses
-    my $RegExp = $ConfigObject->Get('CheckEmailValidAddress');
+    my $RegExp = $Self->{ConfigObject}->Get('CheckEmailValidAddress');
     if ( $RegExp && $Param{Address} =~ /$RegExp/i ) {
         return 1;
     }
     my $Error = '';
 
-    # Workaround for https://github.com/Perl-Email-Project/Email-Valid/issues/36:
-    # remove comment from address when checking.
-    $Param{Address} =~ s{ \s* \( [^()]* \) \s* $ }{}smxg;
-
     # email address syntax check
-    if ( !Email::Valid->address( $Param{Address} ) ) {
+    if (
+        $Param{Address}
+        !~ m{
+            ^
+            [a-zA-Z0-9_#]+
+            (?:
+                [a-zA-Z0-9_+\.&%-/=]*
+                [a-zA-Z0-9_'\.-]+
+            )?
+            @
+            (?:
+                (?:
+                    [a-zA-Z0-9]+
+                    ([a-zA-Z0-9\.-]*[a-zA-Z0-9]+)?
+                    \.+
+                    [a-zA-Z]{2,8}
+                )
+                |
+                (?:
+                    \d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}
+                )
+            )
+            $
+        }x
+        )
+    {
         $Error = "Invalid syntax";
         $Self->{ErrorType} = 'InvalidSyntax';
     }
 
+    # email address syntax check
     # period (".") may not be used to end the local part,
     # nor may two or more consecutive periods appear
-    elsif ( $Param{Address} =~ /(\.\.)|(\.@)/ ) {
+    if ( $Param{Address} =~ /(\.\.)|(\.@)/ ) {
         $Error = "Invalid syntax";
         $Self->{ErrorType} = 'InvalidSyntax';
     }
 
     # mx check
     elsif (
-        $ConfigObject->Get('CheckMXRecord')
+        $Self->{ConfigObject}->Get('CheckMXRecord')
         && eval { require Net::DNS }    ## no critic
         )
     {
@@ -144,58 +186,53 @@ sub CheckEmail {
         my $Resolver = Net::DNS::Resolver->new();
         if ($Resolver) {
 
-            # it's no fun to have this hanging in the web interface
-            $Resolver->tcp_timeout(3);
-            $Resolver->udp_timeout(3);
-
-            # check if we need to use a specific name server
-            my $Nameserver = $ConfigObject->Get('CheckMXRecord::Nameserver');
+            # check if extra nameserver need to be used
+            my $Nameserver = $Self->{ConfigObject}->Get('CheckMXRecord::Nameserver');
             if ($Nameserver) {
                 $Resolver->nameservers($Nameserver);
             }
 
-            # A-record lookup to verify proper DNS setup
+            # A recorde lookup
             my $Packet = $Resolver->send( $Host, 'A' );
             if ( !$Packet ) {
                 $Self->{ErrorType} = 'InvalidDNS';
                 $Error = "DNS problem: " . $Resolver->errorstring();
-                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                $Self->{LogObject}->Log(
                     Priority => 'error',
-                    Message  => $Error,
+                    Message  => "DNS problem: " . $Resolver->errorstring(),
                 );
             }
+            elsif ( $Packet->header()->ancount() ) {
 
+                # OK
+                # print STDERR "OK A $Host ".$Packet->header->ancount()."\n";
+            }
+
+            # mx recorde lookup
             else {
-                # RFC 5321: first check MX record and fallback to A record if present.
-                # mx record lookup
-                my @MXRecords = Net::DNS::mx( $Resolver, $Host );
-
-                if ( !@MXRecords ) {
-
-                    $Kernel::OM->Get('Kernel::System::Log')->Log(
-                        Priority => 'debug',
-                        Message =>
-                            "$Host has no mail exchanger (MX) defined, trying A resource record instead.",
+                my $Packet = $Resolver->send( $Host, 'MX' );
+                if ( !$Packet ) {
+                    $Self->{ErrorType} = 'InvalidDNS';
+                    $Error = "DNS problem: " . $Resolver->errorstring();
+                    $Self->{LogObject}->Log(
+                        Priority => 'error',
+                        Message  => "DNS problem: " . $Resolver->errorstring(),
                     );
+                }
+                elsif ( $Packet->header()->ancount() ) {
 
-                    # see if our previous A-record lookup returned a RR
-                    if ( scalar $Packet->answer() eq 0 ) {
-
-                        $Self->{ErrorType} = 'InvalidMX';
-                        $Error = "$Host has no mail exchanger (MX) or A resource record defined.";
-
-                        $Kernel::OM->Get('Kernel::System::Log')->Log(
-                            Priority => 'debug',
-                            Message  => $Error,
-                        );
-                    }
+                    # OK
+                    # print STDERR "OK MX $Host ".$Packet->header->ancount()."\n";
+                }
+                else {
+                    $Error = "no mail exchanger (mx) found!";
+                    $Self->{ErrorType} = 'InvalidMX';
                 }
             }
         }
     }
-    elsif ( $ConfigObject->Get('CheckMXRecord') ) {
-
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+    elsif ( $Self->{ConfigObject}->Get('CheckMXRecord') ) {
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Can't load Net::DNS, no mx lookups possible",
         );
@@ -205,7 +242,7 @@ sub CheckEmail {
     if ( !$Error ) {
 
         # check special stuff
-        my $RegExp = $ConfigObject->Get('CheckEmailInvalidAddress');
+        my $RegExp = $Self->{ConfigObject}->Get('CheckEmailInvalidAddress');
         if ( $RegExp && $Param{Address} =~ /$RegExp/i ) {
             $Self->{Error}     = "invalid $Param{Address} (config)!";
             $Self->{ErrorType} = 'InvalidConfig';
@@ -221,7 +258,7 @@ sub CheckEmail {
     }
 }
 
-=head2 StringClean()
+=item StringClean()
 
 clean a given string
 
@@ -240,7 +277,7 @@ sub StringClean {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{StringRef} || ref $Param{StringRef} ne 'SCALAR' ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => 'Need a scalar reference!'
         );
@@ -250,16 +287,6 @@ sub StringClean {
     return $Param{StringRef} if !defined ${ $Param{StringRef} };
     return $Param{StringRef} if ${ $Param{StringRef} } eq '';
 
-    # check for invalid utf8 characters and remove invalid strings
-    if ( !utf8::valid( ${ $Param{StringRef} } ) ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "Removed string containing invalid utf8: '${ $Param{StringRef} }'!",
-        );
-        ${ $Param{StringRef} } = '';
-        return;
-    }
-
     # set default values
     $Param{TrimLeft}  = defined $Param{TrimLeft}  ? $Param{TrimLeft}  : 1;
     $Param{TrimRight} = defined $Param{TrimRight} ? $Param{TrimRight} : 1;
@@ -282,7 +309,7 @@ sub StringClean {
     return $Param{StringRef};
 }
 
-=head2 CreditCardClean()
+=item CreditCardClean()
 
 clean a given string and remove credit card
 
@@ -296,7 +323,7 @@ sub CreditCardClean {
     my ( $Self, %Param ) = @_;
 
     if ( !$Param{StringRef} || ref $Param{StringRef} ne 'SCALAR' ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => 'Need a scalar reference!'
         );
@@ -321,12 +348,14 @@ sub CreditCardClean {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
