@@ -1,8 +1,6 @@
 # --
 # Kernel/System/CustomerUser/DB.pm - some customer user functions
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: DB.pm,v 1.88.2.3 2012-12-03 10:39:00 jh Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,12 +14,12 @@ use warnings;
 
 use Crypt::PasswdMD5 qw(unix_md5_crypt);
 
-use Kernel::System::CheckItem;
-use Kernel::System::Valid;
 use Kernel::System::Cache;
+use Kernel::System::CheckItem;
+use Kernel::System::Time;
+use Kernel::System::Valid;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.88.2.3 $) [1];
+use vars qw(@ISA);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -31,20 +29,19 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (
+    for my $Needed (
         qw(DBObject ConfigObject LogObject PreferencesObject CustomerUserMap MainObject EncodeObject)
         )
     {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
+        $Self->{$Needed} = $Param{$Needed} || die "Got no $Needed!";
     }
 
-    # create valid object
-    $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
-
-    # create check item object
+    # create additional objects
     $Self->{CheckItemObject} = Kernel::System::CheckItem->new( %{$Self} );
+    $Self->{TimeObject}      = Kernel::System::Time->new( %{$Self} );
+    $Self->{ValidObject}     = Kernel::System::Valid->new( %{$Self} );
 
-    # max shown user a search list
+    # max shown user per search list
     $Self->{UserSearchListLimit} = $Self->{CustomerUserMap}->{CustomerUserSearchListLimit} || 250;
 
     # config options
@@ -65,7 +62,7 @@ sub new {
     $Self->{DestCharset}         = $Self->{CustomerUserMap}->{Params}->{DestCharset}         || '';
     $Self->{CharsetConvertForce} = $Self->{CustomerUserMap}->{Params}->{CharsetConvertForce} || '';
 
-    # db connection settings, disable Encode utf8 if source db is no utf8
+    # db connection settings, disable Encode utf8 if source db is not utf8
     my %DatabasePreferences;
     if ( $Self->{SourceCharset} !~ /utf(-8|8)/i ) {
         $DatabasePreferences{Encode} = 0;
@@ -87,12 +84,12 @@ sub new {
         }
     }
 
-    # create cache object
+    # set cache type
+    $Self->{CacheType} = 'CustomerUser' . $Param{Count};
+
+    # create cache object, but only if CacheTTL is set in customer config
     if ( $Self->{CustomerUserMap}->{CacheTTL} ) {
         $Self->{CacheObject} = Kernel::System::Cache->new( %{$Self} );
-
-        # set cache type
-        $Self->{CacheType} = 'CustomerUser' . $Param{Count};
     }
 
     # create new db connect if DSN is given
@@ -127,15 +124,22 @@ sub CustomerName {
         return;
     }
 
+    # check cache
+    if ( $Self->{CacheObject} ) {
+        my $Name = $Self->{CacheObject}->Get(
+            Type => $Self->{CacheType},
+            Key  => "CustomerName::$Param{UserLogin}",
+        );
+        return $Name if defined $Name;
+    }
+
     # build SQL string 1/2
-    my $SQL = "SELECT $Self->{CustomerKey} ";
+    my $SQL = "SELECT ";
     if ( $Self->{CustomerUserMap}->{CustomerUserNameFields} ) {
-        for my $Entry ( @{ $Self->{CustomerUserMap}->{CustomerUserNameFields} } ) {
-            $SQL .= ", $Entry";
-        }
+        $SQL .= join( ", ", @{ $Self->{CustomerUserMap}->{CustomerUserNameFields} } );
     }
     else {
-        $SQL .= " , first_name, last_name ";
+        $SQL .= "first_name, last_name ";
     }
     $SQL .= " FROM $Self->{CustomerTable} WHERE ";
 
@@ -161,37 +165,24 @@ sub CustomerName {
         }
     }
 
-    # check cache
-    if ( $Self->{CacheObject} ) {
-        my $Name = $Self->{CacheObject}->Get(
-            Type => $Self->{CacheType},
-            Key  => "CustomerName::$SQL",
-        );
-        return $Name if defined $Name;
-    }
-
     # get data
-    my $Name       = '';
     my $SQLConvert = $Self->_ConvertTo($SQL);
     return if !$Self->{DBObject}->Prepare( SQL => $SQLConvert, Limit => 1 );
+    my @NameParts;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
-        for my $Position ( 1 .. 8 ) {
-            next if !$Row[$Position];
-            $Row[$Position] = $Self->_ConvertFrom( $Row[$Position] );
-            if ( !$Name ) {
-                $Name = $Row[$Position];
-            }
-            else {
-                $Name .= ' ' . $Row[$Position];
-            }
+        for my $Field (@Row) {
+            next if !$Field;
+            push @NameParts, $Field;
         }
     }
+    my $Name = join( ' ', @NameParts );
+    $Name = $Self->_ConvertFrom($Name);
 
     # cache request
     if ( $Self->{CacheObject} ) {
         $Self->{CacheObject}->Set(
             Type  => $Self->{CacheType},
-            Key   => "CustomerName::$SQL",
+            Key   => "CustomerName::$Param{UserLogin}",
             Value => $Name,
             TTL   => $Self->{CustomerUserMap}->{CacheTTL},
         );
@@ -206,10 +197,11 @@ sub CustomerSearch {
     my $Valid = defined $Param{Valid} ? $Param{Valid} : 1;
 
     # check needed stuff
-    if ( !$Param{Search} && !$Param{UserLogin} && !$Param{PostMasterSearch} ) {
+    if ( !$Param{Search} && !$Param{UserLogin} && !$Param{PostMasterSearch} && !$Param{CustomerID} )
+    {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => 'Need Search, UserLogin or PostMasterSearch!',
+            Message  => 'Need Search, UserLogin, PostMasterSearch or CustomerID!',
         );
         return;
     }
@@ -290,6 +282,17 @@ sub CustomerSearch {
             }
         }
     }
+    elsif ( $Param{CustomerID} ) {
+
+        my $CustomerID = $Self->{DBObject}->Quote( $Param{CustomerID}, 'Like' );
+        $CustomerID =~ s/\*/%/g;
+        if ( $Self->{CaseSensitive} ) {
+            $SQL .= "$Self->{CustomerID} LIKE '$CustomerID' $LikeEscapeString";
+        }
+        else {
+            $SQL .= "LOWER($Self->{CustomerID}) LIKE LOWER('$CustomerID') $LikeEscapeString";
+        }
+    }
 
     # add valid option
     if ( $Self->{CustomerUserMap}->{CustomerValid} && $Valid ) {
@@ -301,10 +304,10 @@ sub CustomerSearch {
     # check cache
     if ( $Self->{CacheObject} ) {
         my $Users = $Self->{CacheObject}->Get(
-            Type => $Self->{CacheType},
+            Type => $Self->{CacheType} . '_CustomerSearch',
             Key  => "CustomerSearch::$SQL",
         );
-        return %{$Users} if $Users;
+        return %{$Users} if ref $Users eq 'HASH';
     }
 
     # get data
@@ -326,7 +329,7 @@ sub CustomerSearch {
     # cache request
     if ( $Self->{CacheObject} ) {
         $Self->{CacheObject}->Set(
-            Type  => $Self->{CacheType},
+            Type  => $Self->{CacheType} . '_CustomerSearch',
             Key   => "CustomerSearch::$SQL",
             Value => \%Users,
             TTL   => $Self->{CustomerUserMap}->{CacheTTL},
@@ -346,7 +349,7 @@ sub CustomerUserList {
             Type => $Self->{CacheType},
             Key  => "CustomerUserList::$Valid",
         );
-        return %{$Users} if $Users;
+        return %{$Users} if ref $Users eq 'HASH';
     }
 
     # do not use valid option if no valid option is used
@@ -374,6 +377,70 @@ sub CustomerUserList {
     return %Users;
 }
 
+sub CustomerIDList {
+    my ( $Self, %Param ) = @_;
+
+    my $Valid = defined $Param{Valid} ? $Param{Valid} : 1;
+    my $SearchTerm = $Param{SearchTerm} || '';
+
+    my $CacheType = $Self->{CacheType} . '_CustomerIDList';
+    my $CacheKey  = "CustomerIDList::${Valid}::$SearchTerm";
+
+    # check cache
+    if ( $Self->{CacheObject} ) {
+        my $Result = $Self->{CacheObject}->Get(
+            Type => $CacheType,
+            Key  => $CacheKey,
+        );
+        return @{$Result} if ref $Result eq 'ARRAY';
+    }
+
+    my $SQL .= "
+        SELECT DISTINCT($Self->{CustomerID})
+        FROM $Self->{CustomerTable}
+        WHERE 1 = 1 ";
+
+    # add valid option
+    if ( $Self->{CustomerUserMap}->{CustomerValid} && $Valid ) {
+        my $ValidIDs = join( ', ', $Self->{ValidObject}->ValidIDsGet() );
+        $SQL .= "
+            AND $Self->{CustomerUserMap}->{CustomerValid} IN ($ValidIDs) ";
+    }
+
+    # add search term
+    if ($SearchTerm) {
+        my $SearchTermEscaped = $Self->{DBObject}->QueryStringEscape( QueryString => $SearchTerm );
+
+        $SQL .= ' AND ';
+        $SQL .= $Self->{DBObject}->QueryCondition(
+            Key          => $Self->{CustomerID},
+            Value        => $SearchTermEscaped,
+            SearchPrefix => $Self->{SearchPrefix},
+            SearchSuffix => $Self->{SearchSuffix},
+        );
+        $SQL .= ' ';
+    }
+
+    return if !$Self->{DBObject}->Prepare( SQL => $SQL );
+
+    my @Result;
+
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        push @Result, $Self->_ConvertFrom( $Row[0] );
+    }
+
+    # cache request
+    if ( $Self->{CacheObject} ) {
+        $Self->{CacheObject}->Set(
+            Type  => $CacheType,
+            Key   => $CacheKey,
+            Value => \@Result,
+            TTL   => $Self->{CustomerUserMap}->{CacheTTL},
+        );
+    }
+    return @Result;
+}
+
 sub CustomerIDs {
     my ( $Self, %Param ) = @_;
 
@@ -389,7 +456,7 @@ sub CustomerIDs {
             Type => $Self->{CacheType},
             Key  => "CustomerIDs::$Param{User}",
         );
-        return @{$CustomerIDs} if $CustomerIDs;
+        return @{$CustomerIDs} if ref $CustomerIDs eq 'ARRAY';
     }
 
     # get customer data
@@ -399,10 +466,10 @@ sub CustomerIDs {
     my @CustomerIDs;
     if ( $Data{UserCustomerIDs} ) {
 
-        # used seperators
+        # used separators
         for my $Split ( ';', ',', '|' ) {
 
-            # next if seperator is not there
+            # next if separator is not there
             next if $Data{UserCustomerIDs} !~ /\Q$Split\E/;
 
             # split it
@@ -415,7 +482,7 @@ sub CustomerIDs {
             last;
         }
 
-        # fallback if no seperator got found
+        # fallback if no separator got found
         if ( !@CustomerIDs ) {
             $Data{UserCustomerIDs} =~ s/^\s+//g;
             $Data{UserCustomerIDs} =~ s/\s+$//g;
@@ -464,7 +531,7 @@ sub CustomerUserDataGet {
             Type => $Self->{CacheType},
             Key  => "CustomerUserDataGet::$Param{User}",
         );
-        return %{$Data} if $Data;
+        return %{$Data} if ref $Data eq 'HASH';
     }
 
     # check CustomerKey type
@@ -519,6 +586,13 @@ sub CustomerUserDataGet {
     # get preferences
     my %Preferences = $Self->GetPreferences( UserID => $Data{UserID} );
 
+    # add last login timestamp
+    if ( $Preferences{UserLastLogin} ) {
+        $Preferences{UserLastLoginTimestamp} = $Self->{TimeObject}->SystemTime2TimeStamp(
+            SystemTime => $Preferences{UserLastLogin},
+        );
+    }
+
     # cache request
     if ( $Self->{CacheObject} ) {
         $Self->{CacheObject}->Set(
@@ -538,7 +612,7 @@ sub CustomerUserAdd {
 
     # check ro/rw
     if ( $Self->{ReadOnly} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Customer backend is ro!' );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Customer backend is read only!' );
         return;
     }
 
@@ -559,16 +633,11 @@ sub CustomerUserAdd {
         return;
     }
 
-    # just if no UserLogin is given
+    # if no UserLogin is given
     if ( !$Param{UserLogin} && $Self->{CustomerUserMap}->{AutoLoginCreation} ) {
-        my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WDay ) = localtime( time() );
-        $Year  = $Year - 100;
-        $Year  = "0$Year" if ( $Year < 10 );
-        $Month = $Month + 1;
-        $Month = "0$Month" if ( $Month < 10 );
-        $Day   = "0$Day" if ( $Day < 10 );
-        $Hour  = "0$Hour" if ( $Hour < 10 );
-        $Min   = "0$Min" if ( $Min < 10 );
+        my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $Self->{TimeObject}->SystemTime2Date(
+            SystemTime => $Self->{TimeObject}->SystemTime(),
+        );
         my $Prefix = $Self->{CustomerUserMap}->{AutoLoginCreationPrefix} || 'auto';
         $Param{UserLogin} = "$Prefix-$Year$Month$Day$Hour$Min" . int( rand(99) );
     }
@@ -633,17 +702,20 @@ sub CustomerUserAdd {
 
     # build insert
     my $SQL = "INSERT INTO $Self->{CustomerTable} (";
+    my %SeenKey;    # If the map contains duplicated field names, insert only once.
+    MAPENTRY:
     for my $Entry ( @{ $Self->{CustomerUserMap}->{Map} } ) {
-        if ( $Entry->[0] !~ /^UserPassword$/i ) {
-            $SQL .= " $Entry->[2], ";
-        }
+        next MAPENTRY if ( lc( $Entry->[0] ) eq "userpassword" );
+        next MAPENTRY if $SeenKey{ $Entry->[2] }++;
+        $SQL .= " $Entry->[2], ";
     }
     $SQL .= 'create_time, create_by, change_time, change_by)';
     $SQL .= ' VALUES (';
+    my %SeenValue;
     for my $Entry ( @{ $Self->{CustomerUserMap}->{Map} } ) {
-        if ( $Entry->[0] !~ /^UserPassword$/i ) {
-            $SQL .= " $Value{ $Entry->[0] }, ";
-        }
+        next if ( lc( $Entry->[0] ) eq "userpassword" );
+        next if $SeenValue{ $Entry->[2] }++;
+        $SQL .= " $Value{ $Entry->[0] }, ";
     }
     $SQL .= "current_timestamp, $Param{UserID}, current_timestamp, $Param{UserID})";
     $SQL = $Self->_ConvertTo($SQL);
@@ -660,13 +732,7 @@ sub CustomerUserAdd {
         $Self->SetPassword( UserLogin => $Param{UserLogin}, PW => $Param{UserPassword} );
     }
 
-    # cache reset
-    if ( $Self->{CacheObject} ) {
-        $Self->{CacheObject}->Delete(
-            Type => $Self->{CacheType},
-            Key  => "CustomerUserDataGet::$Param{UserLogin}",
-        );
-    }
+    $Self->_CustomerUserCacheClear( UserLogin => $Param{UserLogin} );
 
     return $Param{UserLogin};
 }
@@ -676,7 +742,7 @@ sub CustomerUserUpdate {
 
     # check ro/rw
     if ( $Self->{ReadOnly} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Customer backend is ro!' );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Customer backend is read only!' );
         return;
     }
 
@@ -730,10 +796,13 @@ sub CustomerUserUpdate {
 
     # update db
     my $SQL = "UPDATE $Self->{CustomerTable} SET ";
+    my %SeenKey;    # If the map contains duplicated field names, insert only once.
+    ENTRY:
     for my $Entry ( @{ $Self->{CustomerUserMap}->{Map} } ) {
-        if ( $Entry->[0] !~ /^UserPassword$/i ) {
-            $SQL .= " $Entry->[2] = $Value{ $Entry->[0] }, ";
-        }
+        next ENTRY if $Entry->[7];                               # skip readonly fields
+        next ENTRY if ( lc( $Entry->[0] ) eq "userpassword" );
+        next ENTRY if $SeenKey{ $Entry->[2] }++;
+        $SQL .= " $Entry->[2] = $Value{ $Entry->[0] }, ";
     }
     $SQL .= " change_time = current_timestamp, ";
     $SQL .= " change_by = $Param{UserID} ";
@@ -786,13 +855,11 @@ sub CustomerUserUpdate {
         $Self->SetPassword( UserLogin => $Param{UserLogin}, PW => $Param{UserPassword} );
     }
 
-    # cache reset
-    if ( $Self->{CacheObject} ) {
-        $Self->{CacheObject}->Delete(
-            Type => $Self->{CacheType},
-            Key  => "CustomerUserDataGet::$Param{UserLogin}",
-        );
+    $Self->_CustomerUserCacheClear( UserLogin => $Param{UserLogin} );
+    if ( $Param{UserLogin} ne $UserData{UserLogin} ) {
+        $Self->_CustomerUserCacheClear( UserLogin => $UserData{UserLogin} );
     }
+
     return 1;
 }
 
@@ -804,7 +871,7 @@ sub SetPassword {
 
     # check ro/rw
     if ( $Self->{ReadOnly} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Customer backend is ro!' );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Customer backend is read only!' );
         return;
     }
 
@@ -918,7 +985,6 @@ sub SetPassword {
                 $SQL .= "LOWER($Param{LoginCol}) = LOWER('"
                     . $Self->{DBObject}->Quote( $Param{UserLogin} ) . "')";
             }
-
         }
 
         return if !$Self->{DBObject}->Do( SQL => $SQL );
@@ -929,13 +995,8 @@ sub SetPassword {
             Message  => "CustomerUser: '$Param{UserLogin}' changed password successfully!",
         );
 
-        # cache reset
-        if ( $Self->{CacheObject} ) {
-            $Self->{CacheObject}->Delete(
-                Type => $Self->{CacheType},
-                Key  => "CustomerUserDataGet::$Param{UserLogin}",
-            );
-        }
+        $Self->_CustomerUserCacheClear( UserLogin => $Param{UserLogin} );
+
         return 1;
     }
 
@@ -946,7 +1007,7 @@ sub SetPassword {
 sub GenerateRandomPassword {
     my ( $Self, %Param ) = @_;
 
-    # Generated passwords are eight characters long by default.
+    # generated passwords are eight characters long by default.
     my $Size = $Param{Size} || 8;
 
     # The list of characters that can appear in a randomly generated password.
@@ -954,16 +1015,15 @@ sub GenerateRandomPassword {
     my @PwChars
         = ( 0 .. 9, 'A' .. 'Z', 'a' .. 'z', '-', '_', '!', '@', '#', '$', '%', '^', '&', '*' );
 
-    # The number of characters in the list.
+    # number of characters in the list.
     my $PwCharsLen = scalar(@PwChars);
 
-    # Generate the password.
+    # generate the password.
     my $Password = '';
     for ( my $i = 0; $i < $Size; $i++ ) {
-        $Password .= $PwChars[ rand($PwCharsLen) ];
+        $Password .= $PwChars[ rand $PwCharsLen ];
     }
 
-    # Return the password.
     return $Password;
 }
 
@@ -976,13 +1036,8 @@ sub SetPreferences {
         return;
     }
 
-    # cache reset
-    if ( $Self->{CacheObject} ) {
-        $Self->{CacheObject}->Delete(
-            Type => $Self->{CacheType},
-            Key  => "CustomerUserDataGet::$Param{UserID}",
-        );
-    }
+    $Self->_CustomerUserCacheClear( UserLogin => $Param{UserID} );
+
     return $Self->{PreferencesObject}->SetPreferences(%Param);
 }
 
@@ -1012,6 +1067,7 @@ sub _ConvertFrom {
     if ( !$Self->{SourceCharset} || !$Self->{DestCharset} ) {
         return $Text;
     }
+
     return $Self->{EncodeObject}->Convert(
         Text  => $Text,
         From  => $Self->{SourceCharset},
@@ -1029,6 +1085,7 @@ sub _ConvertTo {
         $Self->{EncodeObject}->EncodeInput( \$Text );
         return $Text;
     }
+
     return $Self->{EncodeObject}->Convert(
         Text  => $Text,
         To    => $Self->{SourceCharset},
@@ -1037,6 +1094,45 @@ sub _ConvertTo {
     );
 }
 
+sub _CustomerUserCacheClear {
+    my ( $Self, %Param ) = @_;
+
+    return if !$Self->{CacheObject};
+
+    if ( !$Param{UserLogin} ) {
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need UserLogin!' );
+        return;
+    }
+
+    $Self->{CacheObject}->Delete(
+        Type => $Self->{CacheType},
+        Key  => "CustomerUserDataGet::$Param{UserLogin}",
+    );
+    $Self->{CacheObject}->Delete(
+        Type => $Self->{CacheType},
+        Key  => "CustomerName::$Param{UserLogin}",
+    );
+
+    # delete all search cache entries
+    $Self->{CacheObject}->CleanUp(
+        Type => $Self->{CacheType} . '_CustomerIDList',
+    );
+    $Self->{CacheObject}->CleanUp(
+        Type => $Self->{CacheType} . '_CustomerSearch',
+    );
+
+    for my $Function (qw(CustomerUserList)) {
+        for my $Valid ( 0 .. 1 ) {
+            $Self->{CacheObject}->Delete(
+                Type => $Self->{CacheType},
+                Key  => "${Function}::${Valid}",
+            );
+        }
+    }
+
+    return 1;
+}
+
 sub DESTROY {
     my $Self = shift;
 
@@ -1046,6 +1142,7 @@ sub DESTROY {
             $Self->{DBObject}->Disconnect();
         }
     }
+
     return 1;
 }
 
