@@ -1,8 +1,6 @@
 # --
 # Kernel/System/GenericAgent.pm - generic agent system module
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: GenericAgent.pm,v 1.81 2012-02-14 08:40:37 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,12 +14,8 @@ use warnings;
 
 use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
-use Kernel::System::State;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.81 $) [1];
-
 =head1 NAME
 
 Kernel::System::GenericAgent - to manage the generic agent jobs
@@ -113,15 +107,6 @@ sub new {
     # create additional objects
     $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
     $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
-    $Self->{StateObject}        = Kernel::System::State->new(%Param);
-
-    my %PendingStates = $Self->{StateObject}->StateGetStatesByType(
-        StateType => [ 'pending auto', 'pending reminder' ],
-        Result => 'HASH',
-    );
-
-    $Self->{PendingStateList} = \%PendingStates || {};
-    $Self->{CurrentSystemTime} = $Self->{TimeObject}->SystemTime();
 
     # get the dynamic fields for ticket object
     $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
@@ -211,7 +196,7 @@ sub new {
 
         # Add field type to Map
         if ( IsHashRefWithData($FieldValueType) ) {
-            for my $FieldName ( keys %{$FieldValueType} ) {
+            for my $FieldName ( sort keys %{$FieldValueType} ) {
                 $Map{$FieldName} = $FieldValueType->{$FieldName};
             }
         }
@@ -276,7 +261,7 @@ sub JobRun {
         $Self->_JobUpdateRunTime( Name => $Param{Job}, UserID => $Param{UserID} );
 
         # rework
-        for my $Key ( keys %DBJobRaw ) {
+        for my $Key ( sort keys %DBJobRaw ) {
             if ( $Key =~ /^New/ ) {
                 my $NewKey = $Key;
                 $NewKey =~ s/^New//;
@@ -311,19 +296,24 @@ sub JobRun {
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
-        next DYNAMICFIELD
-            if !$DynamicFieldSearchTemplate{ 'Search_DynamicField_' . $DynamicFieldConfig->{Name} };
 
-        # extract the dynamic field value form the Generic Agent Job
-        my $SearchParameter = $Self->{BackendObject}->SearchFieldParameterBuild(
+        # get field value from the information extracted from Generic Agent job
+        my $Value = $Self->{BackendObject}->SearchFieldValueGet(
             DynamicFieldConfig => $DynamicFieldConfig,
             Profile            => \%DynamicFieldSearchTemplate,
-        );
+        ) || '';
 
-        # set search parameter
-        if ( defined $SearchParameter ) {
+        if ($Value) {
+
+            # get search attibutes
+            my $SearchParameter = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
+                DynamicFieldConfig => $DynamicFieldConfig,
+                Value              => $Value,
+            );
+
+            # add search attribute to the search structure
             $DynamicFieldSearchParameters{ 'DynamicField_' . $DynamicFieldConfig->{Name} }
-                = $SearchParameter->{Parameter};
+                = $SearchParameter;
         }
     }
 
@@ -332,12 +322,10 @@ sub JobRun {
     # escalation tickets
     if ( $Job{Escalation} ) {
 
-        # Find all tickets which will escalate within the next five days.
-        #   The notification module will determine if a notification must be sent out or not.
         my @Tickets = $Self->{TicketObject}->TicketSearch(
             Result                           => 'ARRAY',
             Limit                            => 100,
-            TicketEscalationTimeOlderMinutes => -( 5 * 24 * 60 ),
+            TicketEscalationTimeOlderMinutes => -( 3 * 8 * 60 ),       # 3 days, roughly
             Permission                       => 'rw',
             UserID                           => $Param{UserID} || 1,
         );
@@ -413,7 +401,7 @@ sub JobRun {
                 %Tickets
             );
         }
-        for ( keys %Tickets ) {
+        for ( sort keys %Tickets ) {
             my %Ticket = $Self->{TicketObject}->TicketGet(
                 TicketID      => $_,
                 DynamicFields => 0,
@@ -430,14 +418,14 @@ sub JobRun {
 
             # check min. one search arg
             my $Count = 0;
-            for ( keys %Job ) {
+            for ( sort keys %Job ) {
                 if ( $_ !~ /^(New|Name|Valid|Schedule)/ && $Job{$_} ) {
                     $Count++;
                 }
             }
 
             # also search in Dynamic fields search attributes
-            for my $DynamicFieldName ( keys %DynamicFieldSearchParameters ) {
+            for my $DynamicFieldName ( sort keys %DynamicFieldSearchParameters ) {
                 $Count++;
             }
 
@@ -565,7 +553,7 @@ sub JobGet {
             $Data{ $Row[0] } = $Row[1];
         }
     }
-    for my $Key ( keys %Data ) {
+    for my $Key ( sort keys %Data ) {
         if ( $Key =~ /(NewParam)Key(\d)/ ) {
             if ( $Data{"$1Value$2"} ) {
                 $Data{"New$Data{$Key}"} = $Data{"$1Value$2"};
@@ -726,7 +714,7 @@ sub JobAdd {
     }
 
     # insert data into db
-    for my $Key ( keys %{ $Param{Data} } ) {
+    for my $Key ( sort keys %{ $Param{Data} } ) {
         if ( ref $Param{Data}->{$Key} eq 'ARRAY' ) {
             for my $Item ( @{ $Param{Data}->{$Key} } ) {
                 if ( defined $Item ) {
@@ -883,8 +871,6 @@ sub _JobRunTicket {
         }
     }
 
-    my $IsPendingState;
-
     # set new state
     if ( $Param{Config}->{New}->{State} ) {
         if ( $Self->{NoticeSTDOUT} ) {
@@ -895,9 +881,6 @@ sub _JobRunTicket {
             UserID   => $Param{UserID},
             State    => $Param{Config}->{New}->{State},
         );
-
-        $IsPendingState
-            = grep { $_ eq $Param{Config}->{New}->{State} } values %{ $Self->{PendingStateList} };
     }
     if ( $Param{Config}->{New}->{StateID} ) {
         if ( $Self->{NoticeSTDOUT} ) {
@@ -908,43 +891,6 @@ sub _JobRunTicket {
             UserID   => $Param{UserID},
             StateID  => $Param{Config}->{New}->{StateID},
         );
-
-        $IsPendingState
-            = grep { $_ == $Param{Config}->{New}->{StateID} } keys %{ $Self->{PendingStateList} };
-    }
-
-    # set pending time, if new state is pending state
-    if ($IsPendingState) {
-        if ( $Param{Config}->{New}->{PendingTime} ) {
-
-            # pending time
-            my $PendingTime = $Param{Config}->{New}->{PendingTime};
-
-            # calculate pending time based on hours, minutes, years...
-            if ( $Param{Config}->{New}->{PendingTimeType} ) {
-                $PendingTime *= $Param{Config}->{New}->{PendingTimeType};
-            }
-
-            # add systemtime
-            $PendingTime += $Self->{CurrentSystemTime};
-
-            # get date
-            my ( $Sec, $Min, $Hour, $Day, $Month, $Year, $WeekDay )
-                = $Self->{TimeObject}->SystemTime2Date(
-                SystemTime => $PendingTime,
-                );
-
-            # set pending time
-            $Self->{TicketObject}->TicketPendingTimeSet(
-                Year     => $Year,
-                Month    => $Month,
-                Day      => $Day,
-                Hour     => $Hour,
-                Minute   => $Min,
-                TicketID => $Param{TicketID},
-                UserID   => $Param{UserID},
-            );
-        }
     }
 
     # set customer id and customer user
@@ -1298,7 +1244,7 @@ sub _JobUpdateRunTime {
         ),
         ScheduleLastRunUnixTime => $Self->{TimeObject}->SystemTime(),
     );
-    for my $Key ( keys %Insert ) {
+    for my $Key ( sort keys %Insert ) {
         $Self->{DBObject}->Do(
             SQL => 'INSERT INTO generic_agent_jobs (job_name,job_key, job_value) VALUES (?, ?, ?)',
             Bind => [ \$Param{Name}, \$Key, \$Insert{$Key} ],
@@ -1331,9 +1277,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.81 $ $Date: 2012-02-14 08:40:37 $
-
-=cut
