@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/SLA.pm - all sla functions
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::SLA;
@@ -11,30 +12,62 @@ package Kernel::System::SLA;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::Cache',
-    'Kernel::System::CheckItem',
-    'Kernel::System::DB',
-    'Kernel::System::Log',
-    'Kernel::System::Valid',
-);
+use Kernel::System::CheckItem;
+use Kernel::System::Valid;
+
+use vars qw(@ISA);
 
 =head1 NAME
 
 Kernel::System::SLA - sla lib
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 All sla functions.
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
 
-Don't use the constructor directly, use the ObjectManager instead:
+=cut
 
-    my $SLAObject = $Kernel::OM->Get('Kernel::System::SLA');
+=item new()
+
+create an object
+
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::SLA;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
+    my $SLAObject = Kernel::System::SLA->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        DBObject     => $DBObject,
+        MainObject   => $MainObject,
+    );
 
 =cut
 
@@ -45,20 +78,24 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get configured preferences object
-    my $GeneratorModule = $Kernel::OM->Get('Kernel::Config')->Get('SLA::PreferencesModule')
+    # check needed objects
+    for my $Object (qw(DBObject ConfigObject EncodeObject LogObject MainObject)) {
+        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
+    }
+    $Self->{CheckItemObject} = Kernel::System::CheckItem->new( %{$Self} );
+    $Self->{ValidObject}     = Kernel::System::Valid->new( %{$Self} );
+
+    # load generator preferences module
+    my $GeneratorModule = $Self->{ConfigObject}->Get('SLA::PreferencesModule')
         || 'Kernel::System::SLA::PreferencesDB';
-
-    # get preferences object
-    $Self->{PreferencesObject} = $Kernel::OM->Get($GeneratorModule);
-
-    $Self->{CacheType} = 'SLA';
-    $Self->{CacheTTL}  = 60 * 60 * 24 * 20;
+    if ( $Self->{MainObject}->Require($GeneratorModule) ) {
+        $Self->{PreferencesObject} = $GeneratorModule->new(%Param);
+    }
 
     return $Self;
 }
 
-=head2 SLAList()
+=item SLAList()
 
 return a hash list of slas
 
@@ -75,10 +112,7 @@ sub SLAList {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Need UserID!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need UserID!' );
         return;
     }
 
@@ -87,9 +121,6 @@ sub SLAList {
         $Param{Valid} = 1;
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # add ServiceID
     my %SQLTable;
     $SQLTable{sla} = 'sla s';
@@ -97,7 +128,7 @@ sub SLAList {
     if ( $Param{ServiceID} ) {
 
         # quote
-        $Param{ServiceID} = $DBObject->Quote( $Param{ServiceID}, 'Integer' );
+        $Param{ServiceID} = $Self->{DBObject}->Quote( $Param{ServiceID}, 'Integer' );
 
         $SQLTable{service} = 'service_sla r';
         push @SQLWhere, "s.id = r.sla_id AND r.service_id = $Param{ServiceID}";
@@ -106,11 +137,8 @@ sub SLAList {
     # add valid part
     if ( $Param{Valid} ) {
 
-        # get valid object
-        my $ValidObject = $Kernel::OM->Get('Kernel::System::Valid');
-
         # create the valid list
-        my $ValidIDs = join ', ', $ValidObject->ValidIDsGet();
+        my $ValidIDs = join ', ', $Self->{ValidObject}->ValidIDsGet();
 
         push @SQLWhere, "s.valid_id IN ( $ValidIDs )";
     }
@@ -120,20 +148,20 @@ sub SLAList {
     my $WhereString = @SQLWhere ? ' WHERE ' . join q{ AND }, @SQLWhere : '';
 
     # ask database
-    $DBObject->Prepare(
+    $Self->{DBObject}->Prepare(
         SQL => "SELECT s.id, s.name FROM $TableString $WhereString",
     );
 
     # fetch the result
     my %SLAList;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $SLAList{ $Row[0] } = $Row[1];
     }
 
     return %SLAList;
 }
 
-=head2 SLAGet()
+=item SLAGet()
 
 Returns an SLA as a hash
 
@@ -148,13 +176,17 @@ Returns:
           'SLAID'               => '2',
           'Name'                => 'Diamond Pacific - S2',
           'Calendar'            => '2',
-          'FirstResponseTime'   => '60',   # in minutes according to business hours
-          'FirstResponseNotify' => '70',   # in percent
-          'UpdateTime'          => '360',  # in minutes according to business hours
-          'UpdateNotify'        => '70',   # in percent
-          'SolutionTime'        => '960',  # in minutes according to business hours
-          'SolutionNotify'      => '80',   # in percent
-          'ServiceIDs'          => [ '4', '7', '8' ],
+          'FirstResponseTime'   => '60',  # in minutes according to business hours
+          'FirstResponseNotify' => '70',  # in percent
+          'UpdateTime'          => '360', # in minutes according to business hours
+          'UpdateNotify'        => '70',  # in percent
+          'SolutionTime'        => '960', # in minutes according to business hours
+          'SolutionNotify'      => '80',  # in percent
+          'ServiceIDs'          => [
+                                     '4'
+                                     '7'
+                                     '8'
+                                   ],
           'ValidID'             => '1',
           'Comment'             => 'Some Comment',
           'CreateBy'            => '93',
@@ -171,32 +203,19 @@ sub SLAGet {
     # check needed stuff
     for my $Argument (qw(SLAID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $Argument!",
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Argument!" );
             return;
         }
     }
 
     # check if result is already cached
     my $CacheKey = 'Cache::SLAGet::' . $Param{SLAID};
-    my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-        Type           => $Self->{CacheType},
-        Key            => $CacheKey,
-        CacheInMemory  => 1,
-        CacheInBackend => 0,
-    );
-
-    if ( ref $Cached eq 'HASH' ) {
-        return %{$Cached};
+    if ( $Self->{$CacheKey} ) {
+        return %{ $Self->{$CacheKey} };
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # get sla from db
-    $DBObject->Prepare(
+    $Self->{DBObject}->Prepare(
         SQL => 'SELECT id, name, calendar_name, first_response_time, first_response_notify, '
             . 'update_time, update_notify, solution_time, solution_notify, '
             . 'valid_id, comments, create_time, create_by, change_time, change_by '
@@ -209,7 +228,7 @@ sub SLAGet {
 
     # fetch the result
     my %SLAData;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $SLAData{SLAID}               = $Row[0];
         $SLAData{Name}                = $Row[1];
         $SLAData{Calendar}            = $Row[2] || '';
@@ -229,7 +248,7 @@ sub SLAGet {
 
     # check sla
     if ( !$SLAData{SLAID} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "No such SLAID ($Param{SLAID})!",
         );
@@ -237,14 +256,14 @@ sub SLAGet {
     }
 
     # get all service ids
-    $DBObject->Prepare(
+    $Self->{DBObject}->Prepare(
         SQL  => 'SELECT service_id FROM service_sla WHERE sla_id = ? ORDER BY service_id ASC',
         Bind => [ \$SLAData{SLAID} ],
     );
 
     # fetch the result
     my @ServiceIDs;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         push @ServiceIDs, $Row[0];
     }
 
@@ -259,22 +278,13 @@ sub SLAGet {
         %SLAData = ( %SLAData, %Preferences );
     }
 
-    # cache result
-    $Kernel::OM->Get('Kernel::System::Cache')->Set(
-        Type => $Self->{CacheType},
-        TTL  => $Self->{CacheTTL},
-        Key  => $CacheKey,
-
-        # make a local copy of the sla data to avoid it being altered in-memory later
-        Value          => {%SLAData},
-        CacheInMemory  => 1,
-        CacheInBackend => 0,
-    );
+    # cache the result
+    $Self->{$CacheKey} = \%SLAData;
 
     return %SLAData;
 }
 
-=head2 SLALookup()
+=item SLALookup()
 
 returns the name or the sla id
 
@@ -295,52 +305,36 @@ sub SLALookup {
 
     # check needed stuff
     if ( !$Param{SLAID} && !$Param{Name} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => 'Need SLAID or Name!',
         );
         return;
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     if ( $Param{SLAID} ) {
 
         # check cache
         my $CacheKey = 'Cache::SLALookup::ID::' . $Param{SLAID};
-        my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-            Type           => $Self->{CacheType},
-            Key            => $CacheKey,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
-        );
-        if ( defined $Cached ) {
-            return $Cached;
+        if ( defined $Self->{$CacheKey} ) {
+            return $Self->{$CacheKey};
         }
 
         # lookup
-        $DBObject->Prepare(
+        $Self->{DBObject}->Prepare(
             SQL   => 'SELECT name FROM sla WHERE id = ?',
             Bind  => [ \$Param{SLAID}, ],
             Limit => 1,
         );
 
         # fetch the result
-        my $Name = '';
-        while ( my @Row = $DBObject->FetchrowArray() ) {
+        my $Name;
+        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
             $Name = $Row[0];
         }
 
         # cache
-        $Kernel::OM->Get('Kernel::System::Cache')->Set(
-            Type           => $Self->{CacheType},
-            TTL            => $Self->{CacheTTL},
-            Key            => $CacheKey,
-            Value          => $Name,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
-        );
+        $Self->{$CacheKey} = $Name;
 
         return $Name;
     }
@@ -348,44 +342,31 @@ sub SLALookup {
 
         # check cache
         my $CacheKey = 'Cache::SLALookup::Name::' . $Param{Name};
-        my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-            Type           => $Self->{CacheType},
-            Key            => $CacheKey,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
-        );
-        if ( defined $Cached ) {
-            return $Cached;
+        if ( defined $Self->{$CacheKey} ) {
+            return $Self->{$CacheKey};
         }
 
         # lookup
-        $DBObject->Prepare(
+        $Self->{DBObject}->Prepare(
             SQL   => 'SELECT id FROM sla WHERE name = ?',
             Bind  => [ \$Param{Name} ],
             Limit => 1,
         );
 
         # fetch the result
-        my $SLAID = '';
-        while ( my @Row = $DBObject->FetchrowArray() ) {
+        my $SLAID;
+        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
             $SLAID = $Row[0];
         }
 
         # cache
-        $Kernel::OM->Get('Kernel::System::Cache')->Set(
-            Type           => $Self->{CacheType},
-            TTL            => $Self->{CacheTTL},
-            Key            => $CacheKey,
-            Value          => $SLAID,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
-        );
+        $Self->{$CacheKey} = $SLAID;
 
         return $SLAID;
     }
 }
 
-=head2 SLAAdd()
+=item SLAAdd()
 
 add a sla
 
@@ -412,7 +393,7 @@ sub SLAAdd {
     # check needed stuff
     for my $Argument (qw(Name ValidID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $Argument!",
             );
@@ -422,7 +403,7 @@ sub SLAAdd {
 
     # check service ids
     if ( defined $Param{ServiceIDs} && ref $Param{ServiceIDs} ne 'ARRAY' ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => 'ServiceIDs needs to be an array reference!',
         );
@@ -440,23 +421,17 @@ sub SLAAdd {
     $Param{SolutionTime}        ||= 0;
     $Param{SolutionNotify}      ||= 0;
 
-    # get check item object
-    my $CheckItemObject = $Kernel::OM->Get('Kernel::System::CheckItem');
-
     # cleanup given params
     for my $Argument (qw(Name Comment)) {
-        $CheckItemObject->StringClean(
+        $Self->{CheckItemObject}->StringClean(
             StringRef         => \$Param{$Argument},
             RemoveAllNewlines => 1,
             RemoveAllTabs     => 1,
         );
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # find exiting sla's with the same name
-    $DBObject->Prepare(
+    $Self->{DBObject}->Prepare(
         SQL   => 'SELECT id FROM sla WHERE name = ?',
         Bind  => [ \$Param{Name} ],
         Limit => 1,
@@ -464,36 +439,36 @@ sub SLAAdd {
 
     # fetch the result
     my $NoAdd;
-    while ( $DBObject->FetchrowArray() ) {
+    while ( $Self->{DBObject}->FetchrowArray() ) {
         $NoAdd = 1;
     }
 
     # abort insert of new sla, if name already exists
     if ($NoAdd) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "An SLA with the name '$Param{Name}' already exists.",
+            Message  => "Can't add new SLA! '$Param{Name}' already exists.",
         );
         return;
     }
 
     # add sla to database
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => 'INSERT INTO sla '
             . '(name, calendar_name, first_response_time, first_response_notify, '
             . 'update_time, update_notify, solution_time, solution_notify, '
             . 'valid_id, comments, create_time, create_by, change_time, change_by) VALUES '
             . '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
         Bind => [
-            \$Param{Name},                \$Param{Calendar},       \$Param{FirstResponseTime},
-            \$Param{FirstResponseNotify}, \$Param{UpdateTime},     \$Param{UpdateNotify},
-            \$Param{SolutionTime},        \$Param{SolutionNotify}, \$Param{ValidID}, \$Param{Comment},
+            \$Param{Name},                \$Param{Calendar},   \$Param{FirstResponseTime},
+            \$Param{FirstResponseNotify}, \$Param{UpdateTime}, \$Param{UpdateNotify},
+            \$Param{SolutionTime}, \$Param{SolutionNotify}, \$Param{ValidID}, \$Param{Comment},
             \$Param{UserID}, \$Param{UserID},
         ],
     );
 
     # get sla id
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL   => 'SELECT id FROM sla WHERE name = ?',
         Bind  => [ \$Param{Name} ],
         Limit => 1,
@@ -501,13 +476,13 @@ sub SLAAdd {
 
     # fetch the result
     my $SLAID;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $SLAID = $Row[0];
     }
 
     # check sla id
     if ( !$SLAID ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "Can't find SLAID for '$Param{Name}'!",
         );
@@ -515,7 +490,7 @@ sub SLAAdd {
     }
 
     # remove all existing allocations
-    $DBObject->Do(
+    $Self->{DBObject}->Do(
         SQL  => 'DELETE FROM service_sla WHERE sla_id = ?',
         Bind => [ \$SLAID ],
     );
@@ -524,8 +499,8 @@ sub SLAAdd {
     for my $ServiceID ( @{ $Param{ServiceIDs} } ) {
 
         # add one allocation
-        $DBObject->Do(
-            SQL  => 'INSERT INTO service_sla (service_id, sla_id) VALUES (?, ?)',
+        $Self->{DBObject}->Do(
+            SQL => 'INSERT INTO service_sla (service_id, sla_id) VALUES (?, ?)',
             Bind => [ \$ServiceID, \$SLAID ],
         );
     }
@@ -533,7 +508,7 @@ sub SLAAdd {
     return $SLAID;
 }
 
-=head2 SLAUpdate()
+=item SLAUpdate()
 
 update a existing sla
 
@@ -561,7 +536,7 @@ sub SLAUpdate {
     # check needed stuff
     for my $Argument (qw(SLAID Name ValidID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Need $Argument!",
             );
@@ -571,7 +546,7 @@ sub SLAUpdate {
 
     # check service ids
     if ( defined $Param{ServiceIDs} && ref $Param{ServiceIDs} ne 'ARRAY' ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => 'ServiceIDs need to be an array reference!',
         );
@@ -589,23 +564,17 @@ sub SLAUpdate {
     $Param{SolutionTime}        ||= 0;
     $Param{SolutionNotify}      ||= 0;
 
-    # get check item object
-    my $CheckItemObject = $Kernel::OM->Get('Kernel::System::CheckItem');
-
     # cleanup given params
     for my $Argument (qw(Name Comment)) {
-        $CheckItemObject->StringClean(
+        $Self->{CheckItemObject}->StringClean(
             StringRef         => \$Param{$Argument},
             RemoveAllNewlines => 1,
             RemoveAllTabs     => 1,
         );
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # find exiting sla's with the same name
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL   => 'SELECT id FROM sla WHERE name = ?',
         Bind  => [ \$Param{Name} ],
         Limit => 1,
@@ -613,7 +582,7 @@ sub SLAUpdate {
 
     # fetch the result
     my $Update = 0;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         if ( $Row[0] != $Param{SLAID} ) {
             $Update = $Row[0];
         }
@@ -621,44 +590,35 @@ sub SLAUpdate {
 
     # abort update of sla, if name already exists
     if ($Update) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "An SLA with the name '$Param{Name}' already exists.",
+            Message  => "Can't update SLA! '$Param{Name}' already exists.",
         );
         return;
     }
 
     # reset cache
-    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
-        Type => $Self->{CacheType},
-        Key  => 'Cache::SLAGet::' . $Param{SLAID},
-    );
-    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
-        Type => $Self->{CacheType},
-        Key  => 'Cache::SLALookup::Name::' . $Param{Name},
-    );
-    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
-        Type => $Self->{CacheType},
-        Key  => 'Cache::SLALookup::ID::' . $Param{SLAID},
-    );
+    delete $Self->{ 'Cache::SLAGet::' . $Param{SLAID} };
+    delete $Self->{ 'Cache::SLALookup::Name::' . $Param{Name} };
+    delete $Self->{ 'Cache::SLALookup::ID::' . $Param{SLAID} };
 
     # update service
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => 'UPDATE sla SET name = ?, calendar_name = ?, '
             . 'first_response_time = ?, first_response_notify = ?, '
             . 'update_time = ?, update_notify = ?, solution_time = ?, solution_notify = ?, '
             . 'valid_id = ?, comments = ?, change_time = current_timestamp, change_by = ? '
             . 'WHERE id = ?',
         Bind => [
-            \$Param{Name},                \$Param{Calendar},       \$Param{FirstResponseTime},
-            \$Param{FirstResponseNotify}, \$Param{UpdateTime},     \$Param{UpdateNotify},
-            \$Param{SolutionTime},        \$Param{SolutionNotify}, \$Param{ValidID}, \$Param{Comment},
+            \$Param{Name},                \$Param{Calendar},   \$Param{FirstResponseTime},
+            \$Param{FirstResponseNotify}, \$Param{UpdateTime}, \$Param{UpdateNotify},
+            \$Param{SolutionTime}, \$Param{SolutionNotify}, \$Param{ValidID}, \$Param{Comment},
             \$Param{UserID}, \$Param{SLAID},
         ],
     );
 
     # remove all existing allocations
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL  => 'DELETE FROM service_sla WHERE sla_id = ?',
         Bind => [ \$Param{SLAID}, ]
     );
@@ -667,8 +627,8 @@ sub SLAUpdate {
     for my $ServiceID ( @{ $Param{ServiceIDs} } ) {
 
         # add one allocation
-        return if !$DBObject->Do(
-            SQL  => 'INSERT INTO service_sla (service_id, sla_id) VALUES (?, ?)',
+        return if !$Self->{DBObject}->Do(
+            SQL => 'INSERT INTO service_sla (service_id, sla_id) VALUES (?, ?)',
             Bind => [ \$ServiceID, \$Param{SLAID} ],
         );
     }
@@ -676,50 +636,52 @@ sub SLAUpdate {
     return 1;
 }
 
-=head2 SLAPreferencesSet()
+=item SLAPreferencesSet()
 
 set SLA preferences
 
     $SLAObject->SLAPreferencesSet(
-        SLAID  => 123,
-        Key    => 'UserComment',
-        Value  => 'some comment',
-        UserID => 123,
+        SLAID => 123,
+        Key       => 'UserComment',
+        Value     => 'some comment',
+        UserID    => 123,
     );
 
 =cut
 
 sub SLAPreferencesSet {
-    my ( $Self, %Param ) = @_;
+    my $Self = shift;
 
-    return $Self->{PreferencesObject}->SLAPreferencesSet(%Param);
+    return $Self->{PreferencesObject}->SLAPreferencesSet(@_);
 }
 
-=head2 SLAPreferencesGet()
+=item SLAPreferencesGet()
 
 get SLA preferences
 
     my %Preferences = $SLAObject->SLAPreferencesGet(
-        SLAID  => 123,
-        UserID => 123,
+        SLAID => 123,
+        UserID    => 123,
     );
 
 =cut
 
 sub SLAPreferencesGet {
-    my ( $Self, %Param ) = @_;
+    my $Self = shift;
 
-    return $Self->{PreferencesObject}->SLAPreferencesGet(%Param);
+    return $Self->{PreferencesObject}->SLAPreferencesGet(@_);
 }
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
