@@ -12,8 +12,7 @@ package Kernel::System::TicketSearch;
 use strict;
 use warnings;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.21 $) [1];
+use vars qw(@ISA);
 
 use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
@@ -1732,8 +1731,4 @@ This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
-=head1 VERSION
-
-$Revision: 1.21 $ $Date: 2013-01-10 15:20:08 $
-
 =cut
