@@ -3,8 +3,6 @@
 # auto_build.sh - build automatically OTRS tar, rpm and src-rpm
 # Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: auto_build.sh,v 1.108.2.3 2013/01/24 11:18:23 mg Exp $
-# --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
 # the Free Software Foundation; either version 3 of the License, or
@@ -21,7 +19,7 @@
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
-echo "auto_build.sh - build automatically OTRS tar, rpm and src-rpm <\$Revision: 1.108.2.3 $>"
+echo "auto_build.sh - build automatically OTRS tar, rpm and src-rpm"
 echo "Copyright (C) 2001-2013 OTRS AG, http://otrs.org/\n";
 
 PATH_TO_CVS_SRC=$1
@@ -36,10 +34,10 @@ PACKAGE_TMP_SPEC="/tmp/$PACKAGE.spec"
 RPM_BUILD="rpmbuild"
 #RPM_BUILD="rpm"
 
-SUPPORT_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/Support-1.3.5.opm"
+SUPPORT_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/Support-1.4.4.opm"
 #IPHONE_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/iPhoneHandle-1.1.1.opm"
-MANUAL_EN="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.1/en/pdf/otrs_admin_book.pdf"
-MANUAL_DE="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.1/de/pdf/otrs_admin_book.pdf"
+MANUAL_EN="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.2/en/pdf/otrs_admin_book.pdf"
+#MANUAL_DE="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.2/de/pdf/otrs_admin_book.pdf"
 
 
 if ! test $PATH_TO_CVS_SRC || ! test $VERSION || ! test $RELEASE; then
@@ -130,10 +128,8 @@ echo "BUILDHOST = `hostname -f`" >> $RELEASEFILE
 # --
 cd $PACKAGE_BUILD_DIR/$ARCHIVE_DIR/ || exit 1;
 
-# remove CVS dirs
-find $PACKAGE_BUILD_DIR/$ARCHIVE_DIR/ -name CVS | xargs rm -rf || exit 1;
 # remove .cvs ignore files
-find -name ".cvsignore" | xargs rm -rf
+find -name ".gitignore" | xargs rm -rf
 
 #
 # remove old sessions, articles and spool and other stuff
@@ -147,17 +143,18 @@ rm -rf Kernel/Config.pm
 # remove development content
 rm -rf development
 
-# remove swap stuff
+# remove swap/temp stuff
 find -name ".#*" | xargs rm -rf
+find -name ".keep" | xargs rm -f
 
 # include pdf docs
 mkdir -p doc/manual/en
 wget "$MANUAL_EN" || exit 1;
 mv otrs_admin_book.pdf doc/manual/en
 
-mkdir -p doc/manual/de
-wget "$MANUAL_DE" || exit 1;
-mv otrs_admin_book.pdf doc/manual/de
+#mkdir -p doc/manual/de
+#wget "$MANUAL_DE" || exit 1;
+#mv otrs_admin_book.pdf doc/manual/de
 
 # mk ARCHIVE
 bin/otrs.CheckSum.pl -a create
